#
# spec file for package diffoscope
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           diffoscope
Version:        284
Release:        1.1
Summary:        In-depth comparison of files, archives, and directories
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://diffoscope.org/
Source0:        https://diffoscope.org/archive/diffoscope-%{version}.tar.bz2
Source1:        https://diffoscope.org/archive/diffoscope-%{version}.tar.bz2.asc
Source2:        diffoscope.keyring
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.7
BuildRequires:  python3-curses
BuildRequires:  python3-libarchive-c
BuildRequires:  python3-pytest
BuildRequires:  python3-python-magic
BuildRequires:  python3-setuptools
Requires:       python3-curses
Requires:       python3-libarchive-c
Requires:       python3-python-magic
Requires(post): update-alternatives
Requires(postun): update-alternatives
# Tools required for proper function of this program
# in extras_require
Recommends:     python3-distro
Recommends:     python3-argcomplete
Recommends:     python3-defusedxml
Recommends:     python3-jsondiff
Recommends:     python3-progressbar
# for getfacl
Suggests:       acl
# for ar, readelf, objcopy and objdump
Suggests:       binutils
Suggests:       bzip2
# for img2txt
Suggests:       caca-utils
# for isoinfo
Suggests:       cdrkit-cdrtools-compat
# for cbfstool
Suggests:       coreboot-utils
# for stat
Suggests:       coreutils
Suggests:       cpio
# for cmp and diff
Suggests:       diffutils
# for lsattr
Suggests:       e2fsprogs
# for ppudump
Suggests:       fpc
# for msgunfmt
Suggests:       gettext-tools
# for ghc
Suggests:       ghc-compiler
Suggests:       gzip
# for pedump
Suggests:       mono-devel
Suggests:       pdftk
# for pdftotext
Suggests:       poppler-tools
# for RPM unpacking
Suggests:       python3-rpm
Suggests:       sqlite3
# for unsquashfs
Suggests:       squashfs
# for zipinfo
Suggests:       unzip
# for xxd
Suggests:       vim
Suggests:       xz
# currently missing:
# enjarify, javap, lipo, otool, showttf, sng
BuildArch:      noarch

%description
diffoscope will try to get to the bottom of what makes files or
directories different. It will recursively unpack archives of many kinds
and transform various binary formats into more human readable form to
compare them. It can compare two tarballs, ISO images, or PDF just as
easily.

It can be scripted through error codes, and a report can be produced
with the detected differences. The report can be text or HTML.
When no type of report has been selected, diffoscope defaults
to write a text report on the standard output.

diffoscope is developed as part of the `“reproducible builds” Debian
project <https://wiki.debian.org/ReproducibleBuilds>`_.
It is meant to be able to quickly understand why two builds of the same
package produce different outputs. diffoscope was previously named
debbindiff.

%prep
%autosetup -p1
sed -i '0,/#!\/usr\/bin\/env/ d' diffoscope/main.py

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}/
mv %{buildroot}%{_bindir}/diffoscope %{buildroot}%{_bindir}/diffoscope-%{py3_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/diffoscope %{buildroot}%{_bindir}/diffoscope
touch %{buildroot}%{_sysconfdir}/alternatives/diffoscope

%post
%{_sbindir}/update-alternatives --install \
    %{_bindir}/diffoscope diffoscope %{_bindir}/diffoscope-%{py3_ver} 10

%postun
if [ "$1" = 0 ] ; then
    %{_sbindir}/update-alternatives --remove diffoscope %{_bindir}/diffoscope-%{py3_ver}
fi

%check
# test_identification https://salsa.debian.org/reproducible-builds/diffoscope/-/issues/98
py.test-%{python3_bin_suffix} -k 'not (test_python or test_identification or test_obj_identification)'

%files
%doc README.rst
%license COPYING
%{_bindir}/diffoscope
%{_bindir}/diffoscope-%{py3_ver}
%{python3_sitelib}/diffoscope
%{python3_sitelib}/diffoscope-%{version}*-info
%ghost %{_sysconfdir}/alternatives/diffoscope

%changelog
* Sun Dec 22 2024 Sebastian Wagner <sebix@sebix.at>
- update to version 284:
  - Simplify tests_quines.py::test_{differences,differences_deb} to use
  assert_diff and not mangle the expected test output.
  - Update some tests to support file(1) version 5.46.
  (Closes: reproducible-builds/diffoscope#395)
- update test skips, remove test_diff, add test_obj_identification
* Mon Dec  2 2024 Sebastian Wagner <sebix@sebix.at>
- update to version 283:
  - Fix crash when objdump is missing when checking .EFI files.
- update to version 282:
  - Ignore errors when listing .ar archives. (Closes: #1085257)
  - Update copyright years.
- update to version 281:
  - Don't try and test with systemd-ukify within Debian stable.
  - Add support for UKI files.
- update to version 280:
  - Drop Depends on deprecated python3-pkg-resources. (Closes: #1083362)
- update to version 279:
  - Drop removal of calculated basename from readelf output.
  (Closes: reproducible-builds/diffoscope#394)
- update to version 278:
  - Temporarily remove procyon-decompiler from Build-Depends as it was removed
  from testing (#1057532). (Closes: #1082636)
  - Add a helpful contextual message to the output if comparing Debian .orig
  tarballs within .dsc files without the ability to "fuzzy-match" away the
  leading directory. (Closes: reproducible-builds/diffoscope#386)
  - Correctly invert "X%% similar" value and do not emit "100%% similar".
  (Closes: reproducible-builds/diffoscope#391)
  - Update copyright years.
- update to version 277:
  - Don't crash when attempting to hashing symlinks with targets that point to
  a directory.
- update to version 276:
  - Also catch RuntimeError when importing PyPDF so that PyPDF or, crucially,
  its transitive dependencies do not cause diffoscope to traceback at runtime
  and build time. (Closes: #1078944, reproducible-builds/diffoscope#389)
  - Factor out a method for stripping ANSI escapes.
  - Strip ANSI escapes from the output of Procyon. Thanks, Aman Sharma!
  - Update copyright years.
- update to version 275:
  - Update the test_zip.py text fixtures and definitions to support new changes
  to IO::Compress. (Closes: #1078050)
  - Do not call marshal.loads(...) of precompiled Python bytecode as it is
  inherently unsafe. Replace, at least for now, with a brief summary of the
  code section of .pyc files. (Re: reproducible-builds/diffoscope#371)
  - Don't bother to check the Python version number in test_python.py: the
  fixture for this test is deterministic/fixed.
  - Update copyright years.
- update to version 274:
  - Add support for IO::Compress::Zip >= 2.212. (Closes: #1078050)
  - Don't include debug output when calling dumppdf(1).
  - Append output from dumppdf(1) in more cases.
  (Closes: reproducible-builds/diffoscope#387)
  - Update copyright years.
  - Update the available architectures for test dependencies.
- update to version 273:
  - Factor out version detection in test_jpeg_image. (Re:
  reproducible-builds/diffoscope#384)
  - Ensure that 'convert' is from Imagemagick 6.x; we will need to update a
  few things with IM7. (Closes: reproducible-builds/diffoscope#384)
  - Correct import of identify_version after refactoring change in 037bdcbb0.
  - tests:
  + Add OpenSSH key test with a ed25519 key.
  + Skip the OpenSSH test with DSA key if openssh is >> 9.7
  + Support ffmpeg >= 7 that adds some extra context to the diff
  - Do not ignore testing in gitlab-ci.
* Tue Jul  9 2024 Dirk Müller <dmueller@suse.com>
- update to 272:
  * Move away from using DSA OpenSSH keys in tests; support has
    been removed in OpenSSH 9.8p1.
  * Move to assert_diff helper in test_openssh_pub_key.py
  * Update tests to support zipdetails version 4.004 shipped with
    Perl 5.40.
  * Drop apktool from Build-Depends; we can still test our APK
    code via autopkgtests. (Closes: #1071410)
  * Fix tests for 7zip version 24.05.
  * Add a versioned dependency for at least version 5.4.5 for the
    xz tests; they fail under (at least xz 5.2.8).
  * Relax Chris' versioned xz test dependency (5.4.5) to also
    allow version 5.4.1.
  * Include "xz --verbose --verbose" (ie. double --verbose)
    output, not just the single --verbose. (Closes: #1069329)
  * Only include "xz --list" output if the xz has no other
    differences.
  * Use "xz --list" to supplement the output when comparing .xz
    archives; essential when some underlying metadata differs.
  * Actually append the xz --list after the container
    differences, as it simplifies tests and the output.
  * Maintain an in-header boolean state to determine whether to
    drop from-file/to-file lines. This fixes an issue where HTML
    differences were being inadvertendly neglected.
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 265:
  * Ensure that tests with ">=" version constraints actually print
    the corresponding tool name.
    (Closes: reproducible-builds/diffoscope#370)
  * Prevent odt2txt tests from always being skipped due to an
    impossibly new version requirement.
    (Closes: reproducible-builds/diffoscope#369)
  * Avoid nested parens-in-parens when printing "skipping…"
    messages in the testsuite.
- Update to 264:
  * Don't crash on invalid zipfiles, even if we encounter 'badness'
    halfway through the file. (Re: #1068705)
  * Add note when there are duplicate entries in ZIP files.
    (Closes: reproducible-builds/diffoscope!140)
  * Add an external tool reference for GNU Guix for zipdetails.
- Update to 263:
  * Add support for the zipdetails(1) tool included in the Perl
    distribution.
  * Don't use parenthesis within test "skipping…" messages; PyTest
    adds its own parenthesis, so we were ending up with double
    nested parens.
  * Fix the .epub tests after supporting zipdetails(1).
  * Update copyright years and debian/tests/control.
  * Fix MozillaZipContainer's monkeypatch after Python's zipfile
    module changed to detect potentially insecure overlapping
    entries within .zip files.
    (Closes: reproducible-builds/diffoscope#362)
- Update to 262:
  * Factor out Python version checking in test_zip.py. (Re: #362)
  * Also skip some zip tests under 3.10.14 as well; a potential
    regression may have been backported to the 3.10.x series. The
    underlying cause is still to be investigated. (Re: #362)
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 261 (bsc#1220157, CVE-2024-25711):
  * Don't crash if we encounter an .rdb file without an
    equivalent .rdx file.
  * Actually test 7z support in the test_7z set of tests, not the
    lz4 functionality.
  * In addition, correctly check for the 7z binary being
    available (and not lz4) when testing 7z.
  * Prevent a traceback when comparing a contentful .pyc file
    with an empty one. (Re: Debian:#1064973)
  * Don't error-out with a traceback if we encounter
    "struct.unpack"-related errors when parsing .pyc files.
  * Fix compatibility with PyTest 8.0.
  * Don't try and compare rdb_expected_diff on non-GNU systems as
    %%p formatting can vary.
  * Use the 7zip package (over p7zip-full) after package
    transition.
  * Parse the header and hunksize of diffs strictly before
    parsing the context below.
  * Reformat code to comply with the latest version of Black
    (24.1.1).
  * Expand the previous changelog entry to include the CVE number
    that was subsequently assigned.
  * Bump the miniumum Black requirement to run the "Black clean"
    test and make test_zip.py Black clean.
  * CVE-2024-25711: Use a determistic name when extracting
    content from GPG artifacts instead of trusting the value of
    gpg's --use- embedded-filenames.
  * Temporarily fix support for Python 3.11.8 re. a potential
    regression with the handling of ZIP files.
  * Add/fix compatibility for Python progressbar 2.5 & 3.0 etc.
  * Add external tool on GNU Guix for 7z.
  * Improve DOS/MBR extraction by adding support for 7z.
  * Process objdump symbol comment filter inputs as the Python
    "bytes" type (and not str). (Closes: reproducible-
    builds/diffoscope#358)
  * Add a missing RequiredToolNotFound import.
  * Update copyright years.
  * As UI/UX improvement, try and avoid printing an extended
    traceback if diffoscope runs out of memory. This may not
    always be possible to detect.
  * Mark diffoscope as stable in setup.py (for PyPI.org).
    Whatever diffoscope is, at least, not "alpha" anymore.
* Wed Nov  1 2023 Andrea Manzini <andrea.manzini@suse.com>
- removed patch fix-file-5.45.patch as included in upstream
- Update to version 251:
  * If the equivalent of `file -i` returns text/plain, fallback to comparing
    this file as a text file. This especially helps when file(1) miscategorises
    text files as some esoteric type.
- Update to version 250:
  * Fix compatibility with file 5.45.
  * Add external tool references for GNU Guix (for html2text and ttx).
- Update to version 249:
  * Add specialize_as() method, and use it to speed up .smali comparison in APKs.
  * Add documentation for the new specialize_as, and expand the documentation
    of `specialize` too.
  * Correct typos in diffoscope/presenters/utils.py.
- Update to version 246:
  * Add support for LLVM 16.
- Update to version 244:
  * Address compatibility with python-libarchive-c version 5.
  * Testsuite changes
- Update to version 243:
  * Improve the documentation on to produce that binary blob that in the arsc comparator.
* Sat Aug  5 2023 Sebastian Wagner <sebix@sebix.at>
- Add fix-file-5.45.patch to fix compatibility with file version 5.45
  https://salsa.debian.org/reproducible-builds/diffoscope/-/issues/346
- update to version 242:
  - If the binwalk Python module is not available, ensure the user knows they
  may be missing more differences in, for example, concatenated .cpio
  archives.
  - Factor out routine to generate a human-readable comments when
  Python modules are missing.
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 241:
  * Add a missing 'raise' statement
  * document sending out an email upon release
  * Drop the use of include_package_data=True in setup.py.
  * Fix compatibility with pypdf 3.x, and correctly restore test
    data.
  * Rework PDF annotations processing into a separate method.
* Fri Mar  3 2023 Dirk Müller <dmueller@suse.com>
- update to 238:
  * autopkgtest: fix tool name in the skippable list.
  * autopkgtest: only install aapt and dexdump on architectures
    where they are available.
  * Drop backward compatibility assignment.
  * Fix flake warnings, potentially reinstating PyPDF 1.x
    support (untested).
  * Update code to match latest version of Black.
  * Require at least Black version 23.1.0 to run the internal
    Black tests.
  * Update copyright years.
  * Fix compatibility with PyPDF2.
  * Fix compatibility with ImageMagick 7.1.
  * Update from PyPDF2 to pypdf.
  * Add support for Android resources.arsc files.
  * Add support for dexdump.
  * Improve DexFile's FILE_TYPE_RE and add
    FILE_TYPE_HEADER_PREFIX, and remove
    "Dalvik dex file" from ApkFile's FILE_TYPE_RE as well.
  * Update external tool for isoinfo on guix.
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 233:
  * Split packaging metadata into an extras_require.json file instead of using
    the pep517 and the pip modules directly. This was causing build failures if
    not using a virtualenv and/or building without internet access.
  * Add an external tool reference for GNU Guix (lzip).
  * Drop an external tool reference for GNU Guix (pedump).
  * Split inline Python code in shell script to generate test dependencies to a
    separate Python script.
  * No need for "from __future__ import print_function" import in setup.py
    anymore.
  * Comment and tidy the new extras_require.json handling.
* Wed Jan 18 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 232:
  * Allow ICC tests to (temporarily) fail.
  * Update debian/tests/control after the addition of PyPDF 3 support.
  * Update regular expression for Android .APK files.
  * Support PyPDF version 3.
- 231:
  * Improve "[X] may produce better output" messages. Based on a patch by
    Helmut Grohne. (Closes: #1026982)
- 230:
  * Fix compatibility with file(1) version 5.43; thanks, Christoph Biedl.
  * Support Berkeley DB version 6.
- 229:
  * Skip test_html.py::test_diff if html2text is not installed.
    (Closes: #1026034)
  * Bump standards version to 4.6.2, no changes needed.
- 228:
  * As an optimisation, don't run apktool if no differences are detected before
    the signing block. (Closes: reproducible-builds/diffoscope!105)
  * Support both the python3-progressbar and python3-progressbar2 Debian
    packages, two modules providing the "progressbar" Python module.
    (Closes: reproducible-builds/diffoscope#323)
  * Ensure we recommend apksigcopier. (Re: reproducible-builds/diffoscope!105)
  * Make the code clearer around generating the Debian substvars and tidy
    generation of os_list.
  * Update copyright years.
- 227:
  * Don't attempt to attach text-only differences notice if there are no
    differences to begin with. (Closes: #1024171, #1024349)
  * Don't run Python decompiling tests on Python bytecode that both file(1)
    cannot yet detect and Python 3.11 cannot demarshall. (Closes: #1024335)
- 226:
  * Add an lzip comparator with tests.
  * Add support for comparing the "text" content of HTML files using html2text.
    (Closes: #1022209, reproducible-builds/diffoscope#318)
  * Misc/test improvements:
  * Drop the ALLOWED_TEST_FILES test; it's mostly just annoying.
  * Drop other copyright notices from lzip.py and test_lzip.py.
  * Use assert_diff helper in test_lzip.py.
  * Pylint tests/test_source.py.
  * Add lzip to debian dependencies.
- 225:
  * Add support for detecting ordering-only differences in XML files.
    (Closes: #1022146)
  * Fix an issue with detecting ordering differences. (Closes: #1022145)
  * Add support for ttx(1) from fonttools.
    (Re: reproducible-builds/diffoscope#315)
  * Test improvements:
  - Tidy up the JSON tests and use assert_diff over get_data and manual
    assert in XML tests.
  - Rename order1.diff to json_expected_ordering_diff for consistency.
  - Temporarily allow the stable-po pipeline to fail in the CI.
  * Use consistently capitalised "Ordering" everywhere we use the word in
    diffoscope's output.
- 224:
  * Fix rlib test failure with LLVM 15. Thanks to Gianfranco Costamagna
    (locutusofborg) for the patch.
- 223:
  * The cbfstools utility is now provided in Debian via the coreboot-utils
    Debian package, so we can enable that functionality within Debian.
    (Closes: #1020630)
  * Also include coreboot-utils in Build-Depends and Test-Depends so it is
    available for the tests.
  * Add support for file 5.43.
- 222:
  * Use pep517 and pip to load the requirements. (Closes: #1020091)
  * Remove old Breaks/Replaces in debian/control that have been obsoleted since
    bullseye
* Thu Sep 22 2022 Daniel Garcia <daniel.garcia@suse.com>
- update to version 221:
  - Don't crash if we can open a PDF file with PyPDF but cannot parse the
  annotations within. (Closes: reproducible-builds/diffoscope#311)
  - Depend on the dedicated xxd package, not vim-common.
  - Update external_tools.py to reflect xxd/vim-common change.
- Remove test_python.test_diff because it's failing, it's not recognizing the
  pyc file type with the tests fixtures
  https://salsa.debian.org/reproducible-builds/diffoscope/-/issues/284#note_280561
* Wed Aug 17 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 220:
  - Support Haskell 9.x series files and update the test files to match. Thanks
  to Scott Talbert for the relevant info about the new format.
  (Closes: reproducible-builds/diffoscope#309)
  - Fix a regression introduced in diffoscope version 207 where diffoscope
  would crash if one directory contained a directory that wasn't in the
  other. Thanks to Alderico Gallo for the report and the testcase.
  (Closes: reproducible-builds/diffoscope#310)
- update to version 219:
  - Don't traceback if we encounter an invalid Unicode character in Haskell
  versioning headers. (Closes: reproducible-builds/diffoscope#307)
  - Update various copyright years.
- update to version 218:
  - Improve output of Markdown and reStructuredText to use code blocks with
  syntax highlighting. (Closes: reproducible-builds/diffoscope#306)
- update to version 217:
  - Update test fixtures for GNU readelf 2.38 (now in Debian unstable).
  - Be more specific about the minimum required version of readelf (ie.
  binutils) as it appears that this "patch" level version change resulted in
  a change of output, not the "minor" version. (Closes: #1013348)
  - Don't leak the (likely-temporary) pathname when comparing PDF documents.
* Tue Jun 21 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 216:
  - Print profile output if we were called with --profile and we receive a
  TERM signal.
  - Emit a warning if/when we are handling a TERM signal.
  - Clarify in the code in what situations the main "finally" block gets
  called, especially in relation to handling TERM signals.
  - Clarify and tidy some unconditional control flow in diffoscope.profiling.
- update to version 215:
  - Bug fixes:
  - Also catch IndexError (in addition to ValueError) when parsing .pyc
    files. (Closes: #1012258)
  - Strip "sticky" etc. from "x.deb: sticky Debian binary package […]".
    Thanks to David Prévot for the report. (Closes: #1011635)
  - Correctly package diffoscope's scripts/ directory, fixing the extraction
    of vmlinuz kernel images. (Closes: reproducible-builds/diffoscope#305)
  - Correct the logic for supporting different versions of argcomplete in
    debian/rules.
  - New features:
  - Support both PyPDF 1.x and 2.x.
  - Codebase improvements:
  - Don't call re.compile and then call .sub on the result; just call
    re.sub directly.
  - Clarify the logic around the difference between --usage and --help.
  - Testsuite improvements:
  - Integrate test coverage with GitLab's concept of artifacts.
  - Re-enable Gnumeric tests as its now available again.
  - Test --help and --usage, and additionally test that --help includes
    the programmatically-generated file format list as well.
  - Bump Standards Version field in debian/control to 4.6.1.
* Fri May 27 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 214:
  - Support both python-argcomplete 1.x and 2.x.
  - Add external tool on GNU Guix for xb-tool.
  - Use assert_diff in test_zip over get_data and separate assert.
* Sun May 22 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 213:
  - Don't mask differences in .zip/.jar central directory extra fields.
  - Don't show a binary comparison of .zip/.jar files if we have at least
  one observed nested difference.
  - Use assert_diff in test_zip over get_data and separate assert.
- update to version 212:
  - Add support for extracting vmlinuz/vmlinux Linux kernel images.
  (Closes: reproducible-builds/diffoscope#304)
  - Some Python .pyc files report as "data", so support ".pyc" as a
  fallback extension.
* Sat May  7 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 211:
  * Drop mplayer from the Build-Depends, it's not needed.
* Tue Apr 19 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 210:
  - Make sure that PATH is properly mangled for all diffoscope actions, not
  just when running comparators.
* Fri Apr  1 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 209:
  - Update R test fixture for R 4.2.x series. (Closes: #1008446)
  - Update minimum version of Black to prevent test failure on Ubuntu jammy.
* Fri Mar 25 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 208:
  - Add graceful handling for UNIX sockets and named pipes.
  (Closes: reproducible-builds/diffoscope#292)
  - Remove a superfluous log message and reformatt comment lines.
  - Reformat various files to satisfy current version of Black.
* Fri Mar  4 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 207:
  - Fix a gnarly regression when comparing directories against non-directories.
  (Closes: reproducible-builds/diffoscope#292)
  - Use our assert_diff utility where we can within test_directory.py
* Fri Feb 25 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 206:
  - Also allow "Unicode text, UTF-8 text" as well as "UTF-8 Unicode text" to
  match for .buildinfo files too.
  - Add a test for recent file(1) issue regarding .changes files.
  (Re: reproducible-builds/diffoscope#291)
  - Drop "_PATH" suffix from some module-level globals that are not paths.
* Mon Feb 21 2022 Dirk Müller <dmueller@suse.com>
- update to 205:
  * Fix a file(1)-related regression where .changes files that contained
    non-ASCII text were not identified as being .changes files, resulting in
    seemingly arbitrary packages on tests.reproducible-builds.org and elswhere
    not comparing the package at all. The non-ASCII parts could have been in
    the Maintainer or in the upload changelog, so we were effectively
    penalising anyone outside of the Anglosphere.
    (Closes: reproducible-builds/diffoscope#291)
  * Don't print a warning to the console regarding NT_GNU_BUILD_ID changes in
    ELF binaries.
* Fri Feb 11 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 204:
  - Don't run the binwalk comparator tests as root (or fakeroot) as the
  latest version of binwalk has some security protection against doing
  precisely this.
  - If we fail to scan a file using binwalk, return 'False' from
  BinwalkFile.recognizes rather than raise a traceback.
  - If we fail to import the Python "binwalk" module, don't accidentally report
  that we are missing the "rpm" module instead.
  - Use dependencies to ensure that "diffoscope" and "diffoscope-minimal"
  packages always have the precise same version.
* Fri Feb  4 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 203:
  - Improve documentation for --timeout due to a few misconceptions.
  Add an allowed-to-fail test regarding a regression in directory handling.
  - Tidy control flow in Difference._reverse_self a little.
  - Fix diffing CBFS names that contain spaces.
* Fri Jan 28 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 202:
  - Don't fail if comparing a nonexistent file with a .pyc file (and add test).
  (Closes: #1004312)
  - Drop a reference in the manual page which claims the ability to compare
  non-existent files on the command-line. This has not been possible since
  version 32 which was released in September 2015. (Closes: #1004182)
  - Add experimental support for incremental output support with a timeout.
  Passing, for example, --timeout=60 will mean that diffoscope will not
  recurse into any sub-archives after 60 seconds total execution time has
  elapsed and mark the diff as being incomplete. (Note that this is not a
  fixed/strict timeout due to implementation issues.)
  (Closes: reproducible-builds/diffoscope#301)
  - Don't return with an exit code of 0 if we encounter device file such as
  /dev/stdin with human-readable metadata that matches literal, non-device,
  file contents. (Closes: #1004198)
  - Correct a "recompile" typo.
  - Fix/update whitespace for Black 21.12.
* Fri Jan 21 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 201:
  - If the debian.deb822 module raises any exception on import, re-raise it as
  an ImportError instead. This should fix diffoscope on some Fedora systems.
  Thanks to Mattia Rizzolo for suggesting this particular solution.
  (Closes: reproducible-builds/diffoscope#300)
  - Fix json detection with file-5.41-3.fc36.x86_64.
* Fri Jan 14 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 200:
  - Even if a Sphinx .inv inventory file is labelled "The remainder of this
  file is compressed using zlib", it might not actually be. In this case,
  don't traceback, and simply return the original content.
  (Closes: reproducible-builds/diffoscope#299)
  - Update "X has been modified after NT_GNU_BUILD_ID has been applied" message
  to, for instance, not duplicating the full filename in the primary
  diffoscope's output.
* Fri Jan  7 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 199:
  - Support both variants of "odt2txt", including the one provided by unoconv.
  (Closes: reproducible-builds/diffoscope#298)
  - Add external tool reference on Arch Linux for xb-tool.
* Mon Jan  3 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 198:
  - Support showing "Ordering differences only" within .dsc field values.
  (Closes: #1002002, reproducible-builds/diffoscope#297)
  - Support OCaml versions 4.11, 4.12 and 4.13. (Closes: #1002678)
  - Add support for XMLb files. (Closes: reproducible-builds/diffoscope#295)
  - Also add, for example, /usr/lib/x86_64-linux-gnu to our internal PATH.
  - Also recognize "GnuCash file" files as XML.
* Fri Dec 17 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 197:
  - Drop unnecessary has_same_content_as logging calls.
  - Ignore the new "binary-with-bad-dynamic-table" Lintian tag.
  - Support pgpdump 0.34 in the tests. Thanks to Michael Weiss
  <dev.primeos@gmail.com> for reporting and testing the fix.
* Fri Dec 10 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 196:
  - Add a comment/annotation when the GNU_BUILD_ID field has been modified.
  - Fix the "Black" version detection.
  - Replace "token" with anonymous variable "x" in order to remove extra lines.
* Sun Dec  5 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 195:
  - Don't use the runtime platform's native endianness when unpacking .pyc
  files to fix test failures on big-endian machines.
* Sun Nov 28 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 194:
  - Don't traceback when comparing nested directories with non-directories.
  (Closes: reproducible-builds/diffoscope#288)
* Sat Nov 20 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 193:
  - Don't duplicate file lists at each directory level.
  (Closes: #989192, reproducible-builds/diffoscope#263)
  - When pretty-printing JSON, mark the difference as such, additionally
  avoiding including the full path.
  (Closes: reproducible-builds/diffoscope#205)
  - Codebase improvements:
  - Update a bunch of %%-style string interpolations into f-strings or
    str.format.
  - Import itertools top-level directly.
  - Drop some unused imports.
  - Use isinstance(...) over type(...) ==
  - Avoid aliasing variables if we aren't going to use them.
  - Fix missing diff output on large diffs.
  - Ignore a Python warning coming from a dependent library (triggered by
  supporting Python 3.10)
  - Document that support both Python 3.9 and 3.10.
* Sun Nov 14 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 192:
  - Update .epub test methodology after improving XML file parsing.
- update to version 191:
  - Detect XML files as XML files if either file(1) claims if they are XML
  files, or if they are named .xml.
  (Closes: #999438, reproducible-builds/diffoscope#287)
  - Don't reject Debian .changes files if they contain non-printable
  characters. (Closes: reproducible-builds/diffoscope#286)
  - Continue loading a .changes file even if the referenced files inside it do
  not exist, but include a comment in the diff as a result.
  - Log the reason if we cannot load a Debian .changes file.
  - Fix inverted logic in the assert_diff_startswith() utility.
- update to version 190:
  - Don't raise a traceback if we cannot de-marshal Python bytecode to support
  Python 3.7 loading newer .pyc files.
  (Closes: reproducible-builds/diffoscope#284)
  - Fix Python tests under Python 3.7 with file 5.39+.
  - Skip Python bytecode testing when "file" is older than 5.39.
  - Detect whether the GNU_BUILD_ID field has been modified.
* Tue Nov  2 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 189:
  - Try some alternative suffixes (eg. ".py") to support distributions that
  strip or retain them. (Closes: reproducible-builds/diffoscope#283)
  - Skip Python bytecode testing where we do not have an expected diff.
  (Closes: reproducible-builds/diffoscope#284)
  - Refactor the find_executable utility into an explicit method.
  - Split out a custom call to assert_diff to support a .startswith equivalent.
  - Use skipif instead of manual conditionals in some tests.
  - Add an external tool reference for Guix to support ppudump and dumppdf.
  - Update uImage test output for file(1) version 5.41.
  - Add Arch Linux as CI test target.
  - Add external tools on Arch Linux for ffmpeg, openssl and ocalobjinfo.
* Fri Oct 22 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 188:
  - Add support for Python Sphinx inventory files, usually named objects.inv.
  - Fix Python bytecode decompilation tests with Python 3.10+.
  (Closes: reproducible-builds/diffoscope#278)
* Sat Oct  9 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 187:
  - Add support for comparing .pyc files. Thanks to Sergei Trofimovich.
  (Closes: reproducible-builds/diffoscope#278)
* Fri Oct  1 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 186:
  - Don't call close_archive when garbage-collecting Archive instances unless
  open_archive returned successfully. This prevents, amongst others, an
  AttributeError traceback due to PGPContainer's cleanup routines assuming
  that its temporary directory had been created.
  (Closes: reproducible-builds/diffoscope#276)
  - Ensure that the string "RPM archives" exists in the package description,
  regardless of whether python3-rpm is installed or not at build time.
  - Fix the LVM Macho comparator for non-x86-64 architectures.
* Fri Sep 24 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 185:
  - Fix the autopkgtest in order to fix testing migration: the androguard
  Python module is not in the python3-androguard Debian package
  - Ignore a warning in the tests from the h5py package that doesn't concern
  diffoscope.
  - Bump Standards-Version to 4.6.0.
* Sat Sep 18 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 184:
  - Fix the semantic comparison of R's .rdb files after a refactoring of
  temporary directory handling in a previous version.
  - Support a newer format version of R's .rds files.
  - Update tests for OCaml 4.12. (Closes: reproducible-builds/diffoscope#274)
  - Move diffoscope.versions to diffoscope.tests.utils.versions.
  - Use assert_diff in tests/comparators/test_rdata.py.
  - Reformat various modules with Black.
  - Stop using the deprecated distutils module by adding a version
  comparison class based on the RPM version rules.
  - Update invocations of llvm-objdump for the latest version of LLVM.
  - Adjust a test with one-byte text file for file(1) version 5.40.
  - Improve the parsing of the version of OpenSSH.
  - Add a --diff-context option to control the unified diff context size.
  (reproducible-builds/diffoscope!88)
* Sat Sep  4 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 183:
  - Add support for extracting Android signing blocks.
  (Closes: reproducible-builds/diffoscope#246)
  - Format debug messages for elf sections using our
  diffoscope.utils.format_class utility.
  - Clarify a comment about the HUGE_TOOLS dict in diffoscope.external_tools.
  - Clarify output around APK Signing Blocks and remove an accidental duplicate
  "0x" prefix.
* Sun Aug 29 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 182:
  - Also ignore, for example, spurious "fwGCC: (Debian ... )" lines in output
  from strings(1).
  - Only use "java -jar /path/to/apksigner.jar" if we have a .jar as newer
  versions of apksigner use a shell wrapper script which will obviously be
  rejected by the JVM. Also mention in the diff if apksigner is missing.
  - Pass "-f" to apktool to avoid creating a strangely-named subdirectory and
  to simplify code.
  - If we specify a suffix for temporary file or directory, ensure it starts
  with a "_" to make the generated filenames more human-readable.
  - Drop an unused File import.
  - Update the minimum version of the Black source code formatter.
  - Support parsing the return value of squashfs versions which discriminate
  between fatal and non-fatal errors.
* Fri Aug 20 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 181:
  - New features and bug fixes:
  - Don't require apksigner in order to compare .apk files using apktool.
  - Add a special-case to squshfs image extraction to not fail if we aren't
    root/superuser. (Closes: #991059)
  - Reduce the maximum line length to avoid O(n^2) Wagner-Fischer algorithm,
    which meant that diff generation took an inordinate amount of time.
    (Closes: reproducible-builds/diffoscope#272)
  - Include profiling information in --debug output if --profile is not set.
  - Don't print an orphan newline when the Black source code formatter
    self-test passes.
  - Tests:
  - Update test to check specific contents of squashfs listing, otherwise it
    fails depending on the test systems uid-to-username mapping in passwd(5).
  - Assign "seen" and "expected" values to local variables to improve
    contextual information in/around failed tests.
  - Misc changes:
  - Print the size of generated HTML, text (etc.) reports.
  - Profile calls to specialize and diffoscope.diff.linediff.
  - Update various copyright years.
* Sun Aug  8 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 180:
  - Don't include specific ".debug"-like lines in the output, as it invariably
  a duplicate of the debug ID that exists in a better form in the readelf(1)
  differences for this file.
  - Also ignore include short "GCC" lines that differs on a single prefix byte
  too. These are distracting, not very useful and are simply the strings(1)
  command's idea of the build ID, which, again, is displayed nearby in the
  file's diff.
  - Update the invocation arguments and tests for the latest version of
  odt2txt.
* Fri Jul 30 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 179:
  - Ensure that various LLVM tools are installed, even when testing whether
  a MacOS binary has zero differences when compared to itself.
  (Closes: reproducible-builds/diffoscope#270)
* Sun Jul 18 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 178:
  - Don't traceback on an broken symlink in a directory.
  (Closes: reproducible-builds/diffoscope#269)
  - Rewrite the calculation of a file's "fuzzy hash" to make the control
  flow cleaner.
  - Support .deb package members compressed with the Zstandard algorithm.
  (LP: #1923845)
  - Overhaul the Mach-O executable file comparator.
  - Implement tests for the Mach-O comparator.
  - Switch to new argument format for the LLVM compiler.
  - Fix test_libmix_differences in testsuite for the ELF format.
  - Improve macOS compatibility for the Mach-O comparator.
  - Add llvm-readobj and llvm-objdump to the internal EXTERNAL_TOOLS data
  structure.
  - Invoke gzip(1) with the short option variants to support Busybox's gzip.
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 177:
  * Improve support for Apple "provisioning profiles".
* Sat May 29 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update ffmpeg tests to work with ffmpeg 4.4.
  (Closes: reproducible-builds/diffoscope#258)
* Fri May 14 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 175:
  * Use the actual filesystem path name (instead of diffoscope's concept of the
    source name) to correct APK filename filtering when an APK file is in
    another container -- we need to filter the auto-generated "1.apk" instead
    of "original-filename.apk". (Closes: reproducible-builds/diffoscope#255)
  * Don't call os.path.basename twice.
  * Correct grammar in a fsimage.py debug message.
  * Add a comment about stripping filenames.
* Fri May  7 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove fix-file-5.40.patch, merged upstream
- update to version 174:
  * Check that we are parsing an actual Debian .buildinfo file, not just
    a file with that extension.
    (Closes: deb#987994, reproducible-builds/diffoscope#254)
  * Support signed .buildinfo files again -- file(1) reports them as
    "PGP signed message".
  * Make the testsuite pass with file(1) version 5.40.
  * Embed some short test fixtures in the test code itself.
  * Fix recognition of compressed .xz files with file(1) 5.40.
* Sun May  2 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove fix-tests-libmix_differences-2.patch, merged upstream
- remove fix-tests-libmix_differences.patch, merged upstream
- added fix-file-5.40.patch
- update to version 173
  * Add support for showing annotations in PDF files.
    (Closes: reproducible-builds/diffoscope#249)
  * Move to assert_diff in test_pdf.py.
  * Difference.__init__: Demote unified_diff argument to a Python "kwarg".
- update to version 172
  * If zipinfo(1) shows a difference but we cannot uncover a difference within
    the underlying .zip or .apk file, add a comment and show the binary
    comparison. (Closes: reproducible-builds/diffoscope#246)
  * Make "error extracting X, falling back to binary comparison E" error
    message nicer.
- update to version 171
  * Do not list as a "skipping reason" tools that do exist.
  * Drop the "compose" tool from the list of required tools for these tests,
    since it doesn't seem to be required.
- update to version 170
  * Avoid frequent long lines in RPM header outputs that cause very very slow
    HTML outputs. (Closes: reproducible-builds/diffoscope#245)
  * Fix test_libmix_differences on openSUSE Tumbleweed.
    (Closes: reproducible-builds/diffoscope#244)
  * Move test_rpm to use the assert_diff utility helper.
  * Add a diffoscope.tools.get_tools() method to support programmatically
    fetching Diffoscope's config.
  * Become tolerant of malformed Debian .changes files.
- update to version 169
  * Optimisations:
  - Use larger buffer/block sizes when extracting files from libarchive-
    based archives.
  - Use a much-shorter CSS class (instead of "diffponct") to dramatically
    reduce uncompressed HTML output.
  * Logging improvements:
  - Don't emit "Unable to stat file" warning/debug messages; we have
    entirely-artificial directory entries such as ELF sections which, of
    course, never exist as filesystem files.
  - Don't emit a "Returning a FooContainer" logging message - we already emit
    "Instantiating a FooContainer" one and are unlikely to fail in the
    middle.
  - Format the report size logging messages when generating HTML reports.
  - Add the target directory when logging which directory we are extracting
    containers to.
  * Miscellaneous:
  - Ignore "--debug" and similar arguments when creating a (hopefully useful)
    temporary directory.
  - Ensure all internal temporary directories have useful names.
  - Clarify a comment regarding diffoscope not extracting excluded files.
  * Skip a DEX-related test if the "procyon" tool is unavailable.
* Tue Mar 16 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- add fix-tests-libmix_differences-2.patch to fix a newline in the other upstream patch
* Mon Mar 15 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- activate test_differences test, as it is fixed in openSUSE TW.
- use fix-tests-libmix_differences.patch based on upstream patch and activate test_limix_differences tests.
* Fri Mar 12 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Disable failing tests explicitly instead of ignoring the exit code.
* Sat Feb 27 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update dependencies
- Update to version 168:
  * Don't call difflib.Differ.compare with very large inputs; it is at least
    O(n^2) and makes diffoscope appear to hang.
    (Closes: reproducible-builds/diffoscope#240)
  * Don't use "Inheriting PATH of X" in debug log message; use "PATH is X".
  * Correct the capitalisation of jQuery.
- Update to version 167:
  * Temporary directory handling:
  - Ensure we cleanup our temporary directory by avoiding confusion between
    the TemporaryDirectory instance and the underlying directory.
    (Closes: deb#981123)
  - Use a potentially-useful suffix to our temporary directory based on the
    command-line passed to diffoscope.
  - Fix some tempfile/weakref interaction in Python 3.7 (ie. Debian buster).
    (Closes: reproducible-builds/diffoscope#239)
  - If our temporary directory does not exist anymore (eg. it has been
    cleaned up in tests, signal handling or reference counting),  make sure
    we recreate it.
  * Bug fixes:
  - Don't rely on magic.Magic(...) to have an identical API between file's
    magic.py and PyPI's "python-magic" library.
    (Closes: reproducible-builds/diffoscope#238)
  - Don't rely on dumpimage returning an appropriate exit code; check that
    the file actually exists after we call it.
  * Codebase changes:
  - Set a default Config.extended_filesystem_attributes.
  - Drop unused Config.acl and Config.xattr attributes.
  - Tidy imports in diffoscope/comparators/fit.py.
  * Tests:
  - Add u-boot-tools to test dependencies so that salsa.debian.org pipelines
    actually test the new FIT comparator.
  - Strip newlines when determining Black version to avoid "requires black
    >= 20.8b1 (18.9b0\n detected)" in test output (NB. embedded newline).
  - Gnumeric is back in testing so re-add to test dependencies.
  - Use assert_diff (over get_data, etc.) in the FIT and APK comparators.
  - Mark test_apk.py::test_android_manifest as being allowed to fail for now.
  - Fix the FIT tests in buster and unstable.
- Update to version 166:
  [ Chris Lamb ]
  * New features and bugfixes:
  - Explicitly remove our top-level temporary directory.
    (Closes: deb#981123, reproducible-builds/diffoscope#234)
  - Increase fuzzy matching threshold to 130 ensure that we show more
    differences. (Closes: reproducible-builds/diffoscope#232)
  - Save our sys.argv in our top-level temporary directory in case it
    helps debug current/errant temporary directories.
  - Prefer to use "magic.Magic" over the "magic.open" compatibility
    interface. (Closes: reproducible-builds/diffoscope#236)
  - Reduce fuzzy threshold to 110 to prevent some test failures.
    (Closes: reproducible-builds/diffoscope#233)
  * Output improvements:
  - Show fuzzyness amount in percentage terms, not out of the
    rather-arbitrary "400".
  - Improve the logging of fuzzy matching.
  - Print the free space in our temporary directory when we create it, not
    from within diffoscope.main.
  * Codebase improvements:
  - Tidy the diffoscopecomparators.utils.fuzzy module.
  - Update my copyright years.
  - Clarify the grammar of a comment.
  - Clarify in a comment that __del__ is not always called, so temporary
    directories are not neccessary removed the *moment* they go out of scope.
  [ Conrad Ratschan ]
  * Fix U-Boot Flattened Image Tree ("FIT") image detection for larger image
    files. (MR: reproducible-builds/diffoscope!75)
- Update to version 165:
  [ Dimitrios Apostolou ]
  * Introduce the --no-acl and --no-xattr arguments [later collapsed to
  - -extended-filesystem-attributes] to improve performance.
  * Avoid calling the external stat command.
  [ Chris Lamb ]
  * Collapse --acl and --xattr into --extended-filesystem-attributes to cover
    all of these extended attributes, defaulting the new option to false (ie.
    to not check these very expensive external calls).
  [ Mattia Rizzolo ]
  * Override several lintian warnings regarding prebuilt binaries in the
  * source.
  * Add a pytest.ini file to explicitly use Junit's xunit2 format.
  * Ignore the Python DeprecationWarning message regarding the `imp` module
    deprecation as it comes from a third-party library.
  * debian/rules: filter the content of the d/*.substvars files
- Update to version 164:
  [ Chris Lamb ]
  * Truncate jsondiff differences at 512 bytes lest they consume the entire page.
  * Wrap our external call to cmp(1) with a profile (to match the internal
    profiling).
  * Add a note regarding the specific ordering of the new
    all_tools_are_listed test.
  [ Dimitrios Apostolou ]
  * Performance improvements:
  - Improve speed of has_same_content by spawning cmp(1) less frequently.
  - Log whenever the external cmp(1) command is spawn.ed
  - Avoid invoking external diff for identical, short outputs.
  * Rework handling of temporary files:
  - Clean up temporary directories as we go along, instead of at the end.
  - Delete FIFO files when the FIFO feeder's context manager exits.
  [ Mattia Rizzolo ]
  * Fix a number of potential crashes in --list-debian-substvars, including
    explicitly listing lipo and otool as external tools.
  - Remove redundant code and let object destructors clean up after themselves.
  [ Conrad Ratschan ]
  * Add a comparator for Flattened Image Trees (FIT) files, a boot image format
    used by U-Boot.
- Update to version 163:
  [ Chris Lamb ]
  * Bug fixes & new features:
  - Normalise "ret" to "retq" in objdump output to support multiple versions
    of obdump(1). (Closes: deb#976760, reproducible-builds/diffoscope#227)
  - Don't show progress indicators when running zstd(1).
    (Closes: reproducible-builds/diffoscope#226)
  - Move the slightly-confusing behaviour of loading an "existing diff" if a
    single file is passed to diffoscope to the new --load-existing-diff
    command.
  * Output improvements:
  - Use pprint.pformat in the JSON comparator to serialise the differences
    from jsondiff to make the output render better.
  - Correct tense in --debug log output.
  * Code quality:
  * Don't use an old-style "super" call.
  - Rewrite the filter routine for post-processing output from readelf(1).
  - Update my copyright years.
  - Remove unncessary PEP 263 encoding lines (replaced via PEP 3120).
  - Use "minimal" instead of "basic" as a variable name to match the
    underlying package name.
  - Add comment regarding Java tests for diffoscope contributors who are not
    using Debian. (Re: reproducible-builds/diffoscope!58)
  * Debian packaging:
  - Update debian/copyright to match copyright notices in source-tree.
    (Closes: reproducible-builds/diffoscope#224)
  - Ensure the new "diffoscope-minimal" package has a different short
    description from the main "diffoscope" one.
  [ Jean-Romain Garnier ]
  * Add tests for OpenJDK 14.
  [ Conrad Ratschan ]
  * Add comparator for "legacy" uboot uImage files.
    (MR: reproducible-builds/diffoscope!69)
- Update to version 162:
  [ Chris Lamb ]
  * Don't depends on radare2 in the Debian autopkgtests as it will not be in
    bullseye due to security considerations (#950372). (Closes: deb#975313)
  * Avoid "Command `s p a c e d o u t` failed" messages when creating an
    artificial CalledProcessError instance in our generic from_operation
    feeder creator.
  * Overhaul long and short descriptions.
  * Use the operation's full name so that "command failed" messages include
    its arguments.
  * Add a missing comma in a comment.
  [ Jelmer Vernooĳ ]
  * Add missing space to the error message when only one argument is passed to
    diffoscope.
  [ Holger Levsen ]
  * Update Standards-Version to 4.5.1.
  [ Mattia Rizzolo ]
  * Split the diffoscope package into a diffoscope-minimal package that
    excludes the larger packages from Recommends. (Closes: deb#975261)
  * Drop support for Python 3.6.
- Update to version 161:
  [ Chris Lamb ]
  * Fix failing testsuite: (Closes: deb#972518)
  - Update testsuite to support OCaml 4.11.1. (Closes: deb#972518)
  - Reapply Black and bump minimum version to 20.8b1.
  * Move the OCaml tests to the assert_diff helper.
  [ Jean-Romain Garnier ]
  * Add support for radare2 as a disassembler.
  [ Paul Spooren ]
  * Automatically deploy Docker images in the continuous integration pipeline.
- Update to version 160:
  * Check that pgpdump is actually installed before attempting to run it.
    Thanks to Gianfranco Costamagna (locutusofborg). (Closes: deb#969753)
  * Add some documentation for the EXTERNAL_TOOLS dictionary.
  * Ensure we check FALLBACK_FILE_EXTENSION_SUFFIX, otherwise we run pgpdump
    against all files that are recognised by file(1) as "data".
- Update to version 159:
  [ Chris Lamb ]
  * Show "ordering differences only" in strings(1) output.
    (Closes: reproducible-builds/diffoscope#216)
  * Don't alias output from "os.path.splitext" to variables that we do not end
    up using.
  * Don't raise exceptions when cleaning up after a guestfs cleanup failure.
  [ Jean-Romain Garnier ]
  * Make "Command" subclass a new generic Operation class.
- Update to version 158:
  * Improve PGP support:
  - Support extracting of files within PGP signed data.
    (Closes: reproducible-builds/diffoscope#214)
  - pgpdump(1) can successfully parse some unrelated, non-PGP binary files,
    so check that the parsed output contains something remotely sensible
    before identifying it as a PGP file.
  * Don't use Python's repr(...)-style output in "Calling external command"
    logging output.
  * Correct a typo of "output" in an internal comment.
- Update to version 157:
  [ Chris Lamb ]
  * Try obsensibly "data" files named .pgp against pgpdump to determine whether
    they are PGP files. (Closes: reproducible-builds/diffoscope#211)
  * Don't raise an exception when we encounter XML files with "<!ENTITY>"
    declarations inside the DTD, or when a DTD or entity references an external
    resource. (Closes: reproducible-builds/diffoscope#212)
  * Temporarily drop gnumeric from Build-Depends as it has been removed from
    testing due to Python 2.x deprecation. (Closes: deb#968742)
  * Codebase changes:
  - Add support for multiple file extension matching; we previously supported
    only a single extension to match.
  - Move generation of debian/tests/control.tmp to an external script.
  - Move to our assert_diff helper entirely in the PGP tests.
  - Drop some unnecessary control flow, unnecessary dictionary comprehensions
    and some unused imports found via pylint.
  * Include the filename in the "... not identified by any comparator"
    logging message.
- Update to version 156:
  [ Chris Lamb ]
  * Update PPU tests for compatibility with Free Pascal versions 3.2.0 or
    greater. (Closes: deb#968124)
  * Emit a debug-level logging message when our ppudump(1) version does not
    match file header.
  * Add and use an assert_diff helper that loads and compares a fixture output
    to avoid a bunch of test boilerplate.
  [ Frazer Clews ]
  * Apply some pylint suggestions to the codebase.
- Update to version 155:
  [ Chris Lamb ]
  * Bump Python requirement from 3.6 to 3.7 - most distributions are either
    shipping3.5 or 3.7, so supporting 3.6 is not somewhat unnecessary and also
    more difficult to test locally.
  * Improvements to setup.py:
  - Apply the Black source code reformatter.
  - Add some URLs for the site of PyPI.org.
  - Update "author" and author email.
  * Explicitly support Python 3.8.
  [ Frazer Clews ]
  * Move away from the deprecated logger.warn method logger.warning.
  [ Mattia Rizzolo ]
  * Document ("classify") on PyPI that this project works with Python 3.8.
- Update to version 154:
  [ Chris Lamb ]
  * Add support for F2FS filesystems.
    (Closes: reproducible-builds/diffoscope#207)
  * Allow "--profile" as a synonym for "--profile=-".
  * Add an add_comment helper method so don't mess with our _comments list
    directly.
  * Add missing bullet point in a previous changelog entry.
  * Use "human-readable" over unhyphenated version.
  * Add a bit more debugging around launching guestfs.
  * Profile the launch of guestfs filesystems.
  * Correct adding a comment when we cannot extract a filesystem due to missing
    guestfs module.
- Update to version 153:
  [ Chris Lamb ]
  * Drop some legacy argument styles; --exclude-directory-metadata and
  - -no-exclude-directory-metadata have been replaced with
  - -exclude-directory-metadata={yes,no}.
  * Code improvements:
  - Make it easier to navigate the main.py entry point.
  - Use a relative import for get_temporary_directory in diffoscope.diff.
  - Rename bail_if_non_existing to exit_if_paths_do_not_exist.
  - Rewrite exit_if_paths_do_not_exist to not check files multiple times.
  * Documentation improvements:
  - CONTRIBUTING.md:
  - Add a quick note about adding/suggesting new options.
  - Update and expand the release process documentation.
  - Add a reminder to regenerate debian/tests/control.
  - README.rst:
  - Correct URL to build job on Jenkins.
  - Clarify and correct contributing info to point to salsa.debian.org.
- Update to version 152:
  [ Chris Lamb ]
  * Bug fixes:
  - Don't require zipnote(1) to determine differences in a .zip file as we
    can use libarchive directly.
  * Reporting improvements:
  - Don't emit "javap not found in path" if it is available in the path but
    it did not result in any actual difference.
  - Fix "... not available in path" messages when looking for Java
    decompilers; we were using the Python class name (eg. "<class
    'diffoscope.comparators.java.Javap'>") over the actual command we looked
    for (eg. "javap").
  * Code improvements:
  - Replace some simple usages of str.format with f-strings.
  - Tidy inline imports in diffoscope.logging.
  - In the RData comparator, always explicitly return a None value in the
    failure cases as we return a non-None value in the "success" one.
  [ Jean-Romain Garnier ]
  * Improve output of side-by-side diffs, detecting added lines better.
    (MR: reproducible-builds/diffoscope!64)
  * Allow passing file with list of arguments to ArgumentParser (eg.
    "diffoscope @args.txt"). (MR: reproducible-builds/diffoscope!62)
- Update to version 151:
  [ Chris Lamb]
  * Improvements and bug fixes:
  - Pass the absolute path when extracting members from SquashFS images as we
    run the command with our working directory set to the temporary
    directory. (Closes: deb#964365, reproducible-builds/diffoscope#189)
  - Increase the minimum length of the output from strings(1) to 8 characters
    to avoid unnecessary diff noise. (Re. reproducible-builds/diffoscope#148)
  * Logging improvements:
  - Fix the compare_files message when the file does not have a literal name.
  - Reduce potential log noise by truncating the has_some_content messages.
  * Codebase changes:
  - Clarify use of a "null" diff in order to remember an exit code.
  - Don't alias a variable when don't end up it; use "_" instead.
  - Use a  "NullChanges" file to represent missing data in the Debian package
    comparator.
  - Update some miscellaneous terms.
- Update to version 150:
  [ Chris Lamb ]
  * Don't crash when listing entries in archives if they don't have a listed
    size (such as hardlinks in .ISO files).
    (Closes: reproducible-builds/diffoscope#188)
  * Dump PE32+ executables (including EFI applications) using objdump.
    (Closes: reproducible-builds/diffoscope#181)
  * Tidy detection of JSON files due to missing call to File.recognizes that
    checks against the output of file(1) which was also causing us to attempt
    to parse almost every file using json.loads. (Whoops.)
  * Drop accidentally-duplicated copy of the new --diff-mask tests.
  * Logging improvements:
  - Split out formatting of class names into a common method.
  - Clarify that we are generating presenter formats in the opening logs.
  [ Jean-Romain Garnier ]
  * Remove objdjump(1) offsets before instructions to reduce diff noise.
    (Closes: reproducible-builds/diffoscope!57)
- Update to version 149:
  [ Chris Lamb ]
  * Update tests for file 5.39. (Closes: reproducible-builds/diffoscope#179)
  * Downgrade the tlsh warning message to an "info" level warning.
    (Closes: deb#888237, reproducible-builds/diffoscope#29)
  * Use the CSS "word-break" property over manually adding U+200B zero-width
    spaces that make copy-pasting cumbersome.
    (Closes: reproducible-builds/diffoscope!53)
  * Codebase improvements:
  - Drop some unused imports from the previous commit.
  - Prevent an unnecessary .format() when rendering difference comments.
  - Use a semantic "AbstractMissingType" type instead of remembering to check
    for both "missing" files and missing containers.
  [ Jean-Romain Garnier ]
  * Allow user to mask/filter reader output via --diff-mask=REGEX.
    (MR: reproducible-builds/diffoscope!51)
  * Make --html-dir child pages open in new window to accommodate new web
    browser content security policies.
  * Fix the --new-file option when comparing directories by merging
    DirectoryContainer.compare and Container.compare.
    (Closes: reproducible-builds/diffoscope#180)
  * Fix zsh completion for --max-page-diff-block-lines.
  [ Mattia Rizzolo ]
  * Do not warn about missing tlsh during tests.
- Update to version 148:
  [ Daniel Fullmer ]
  * Fix a regression in the CBFS comparator due to changes in our_check_output.
  [ Chris Lamb ]
  * Add a remark in the deb822 handling re. potential security issue in the
    .changes, .dsc, .buildinfo comparator.
- Update to version 147:
  [ Chris Lamb ]
  * New features:
  - Add output from strings(1) to ELF binaries. It is intended this will
    expose expose build paths that are hidden somewhere within the objdump(1)
    output. (Closes: reproducible-builds/diffoscope#148)
  - Add basic zsh shell tab-completion support.
    (Closes: reproducible-builds/diffoscope#158)
  * Bug fixes:
  - Prevent a traceback when comparing a PDF document that does not contain
    any metadata, ie. it is missing a PDF "/Info" stanza.
    (Closes: reproducible-builds/diffoscope#150)
  - Fix compatibility with jsondiff 1.2.0 which was causing a traceback and
    log the version of jsondiff we are using to aid debugging in the future.
    (Closes: reproducible-builds/diffoscope#159
  - Fix an issue in GnuPG keybox handling that left filenames in the diff.
  - Don't mask an existing test name; ie. ensure it is actually run.
  * Reporting:
  - Log all calls to subprocess.check_output by using our own wrapper utility.
    (Closes: reproducible-builds/diffoscope#151)
  * Code improvements:
  - Replace references to "WF" with "Wagner-Fischer" for clarity.
  - Drop a large number of unused imports (list_libarchive,
    ContainerExtractionError, etc.)
  - Don't assign exception to a variable that we do not use.
  - Compare string values with the equality operator, not via "is" identity.
  - Don't alias an open file to a variable when we don't use it.
  - Don't alias "filter" builtin.
  - Refactor many small parts of the HTML generation, dropping explicit
    u"unicode" strings, tidying the generation of the "Offset X, Y lines
    modified" messages, moving to PEP 498 f-strings where appropriate, etc.
  - Inline a number of single-used utility methods.
- Update to version 146:
  [ Chris Lamb ]
  * Refactor .changes and .buildinfo handling to show all details (including
    the GPG header and footer components), even when referenced files are not
    present. (Closes: reproducible-builds/diffoscope#122)
  * Normalise filesystem stat(2) "birth times" (ie. st_birthtime) in the same
    way we do with stat(1)'s "Access:" and "Change:" times to fix a
    nondetermistic build failure on GNU Guix.
    (Closes: reproducible-builds/diffoscope#74)
  * Drop the (default) subprocess.Popen(shell=False) keyword argument so that
    the more unsafe shell=True is more obvious.
  * Ignore lower vs. upper-case when ordering our file format descriptions.
  * Don't skip string normalisation in Black.
  [ Mattia Rizzolo ]
  * Add a "py3dist" override for the rpm-python module (Closes: deb#949598)
  * Bump the debhelper compat level to 13 and use the new
    execute_after_*/execture_before_* style rules.
  * Fix a spelling error in changelog.
  [ Daniel Fullmer ]
  * Mount GuestFS filesystem images readonly.
  [ Jean-Romain Garnier ]
  * Prevent an issue where (for example) LibarchiveMember's has_same_content
    method is called regardless of the actual type of file.
- Update to version 145:
  [ Chris Lamb ]
  * Improvements:
  - Add support for Apple Xcode mobile provisioning .mobilepovision files.
    (Closes: reproducible-builds/diffoscope#113)
  - Add support for printing the signatures via apksigner(1).
    (Closes: reproducible-builds/diffoscope#121)
  - Use SHA256 over MD5 when generating page names for the HTML directory
    presenter, validate checksums for files referenced in .changes files
    using SHA256 too, and move to using SHA256 in "Too much input for diff"
    output too. (Closes: reproducible-builds/diffoscope#124)
  - Don't leak the full path of the temporary directory in "Command [..]
    exited with 1".  (Closes: reproducible-builds/diffoscope#126)
  - Identify "iOS App Zip archive data" files as .zip files.
    (Closes: reproducible-builds/diffoscope#116)
  * Bug fixes:
  - Correct "differences" typo in the ApkFile handler.
    (Closes: reproducible-builds/diffoscope#127)
  * Reporting/output improvements:
  - Never emit the same id="foo" TML anchor reference twice, otherwise
    identically-named parts will not be able to linked to via "#foo".
    (Closes: reproducible-builds/diffoscope#120)
  - Never emit HTML with empty "id" anchor lements as it is not possible to
    link to "#" (vs "#foo"). We use "#top" as a fallback value so it will
    work for the top-level parent container.
  - Clarify the message when we cannot find the "debian" Python module.
  - Clarify "Command [..] failed with exit code" to remove duplicate "exited
    with exit" but also to note that diffoscope is interpreting this as an
    error.
  - Add descriptions for the 'fallback' Debian module file types.
  - Rename the --debugger command-line argument to --pdb.
  * Testsuite improvements:
  - Prevent CI (and runtime) apksigner test failures due to lack of
    binfmt_misc on Salsa CI and elsewhere.
  * Codebase improvements:
  - Initially add a pair of comments to tidy up a slightly abstraction level
    violating code in diffoscope.comparators.mising_file and the
    .dsc/.buildinfo file handling, but replace this later by by inlining
    MissingFile's special handling of deb822 to prevent leaking through
    abstraction layers in the first place.
  - Use a BuildinfoFile (etc.) regardless of whether the associated files
    such as the orig.tar.gz and the .deb are present, but don't treat them as
    actual containers. (Re: reproducible-builds/diffoscope#122)
  - Rename the "Openssl" command class to "OpenSSLPKCS7" to accommodate other
    commands with this prefix.
  - Wrap a docstring across multiple lines, drop an inline pprint import and
    comment the HTMLPrintContext class, etc.
  [ Emanuel Bronshtein ]
  * Avoid build-cache in building the released Docker image.
    (Closes: reproducible-builds/diffoscope#123)
  [ Holger Levsen ]
  * Wrap long lines in older changelog entries.
- Update to version 144:
  [ Chris Lamb ]
  * Improvements:
  - Print the amount of free space that we have available in our temporary
    directory as a debugging message.
  - Remove (broken) fuzzy matching of JSON files as file 5.35 (in buster,
    released 2018-10-18) supports recognising JSON data.
    (Closes: reproducible-builds/diffoscope#106)
  - Don't pretty-print the JSON output by default as it will usually be so
    complicated to be unreadable by the human eye and it can be easily
    replaced by piping to "| jq".
  - Don't print a traceback if we pass a single, missing argument to
    diffoscope (eg. a JSON diff to re-load).
  * Reporting/output improvements:
  - Reduce the default number of maximum standard error lines printed from 50
    to 25; usually the error is obvious by that point.
  - Clarify the message when we truncate the number of lines to standard
    error.
  - Clarify when an external command emits for both files, otherwise it can
    look like diffoscope is repeating itself when it is actually being run
    twice.
  - Don't repeat "stderr from {}" if both commands emit the same thing.
  * Dockerfile improvements:
  - Use ARG instead of ENV for DEBIAN_FRONTEND so we do not set this
    environment variable at runtime.
    (Closes: reproducible-builds/diffoscope#103)
  - Run diffoscope as a non-root user in the runtime container.
    (Closes: reproducible-builds/diffoscope#102)
  - Add a .dockerignore file to whitelist files we need in our container.
    Thanks to Emanuel Bronshtein for the original idea.
    (Closes: reproducible-builds/diffoscope#105)
  - Install/remove the build-essential package during build so we can install
    the recommended packages from Git.
  * Testsuite improvements:
  - Include the Black output in the assertion failure too.
  - Update the Black self-test; we don't care about the length of the black
    output, rather whether it has some or, preferably, not.
  * Codebase improvements:
  - Bump the officially required version of Python from 3.5 to 3.6.
    (Closes: reproducible-builds/diffoscope#117)
  - Drop an unused shlex import.
  - Instruct linters to pass over a bare try-except when cleaning up
    temporary files used to extract archives.
  - Format diffoscope/comparators/utils/command.py according to Black
    19.10b0-3.
  - Drop entries from Uploaders that have not uploaded in over three years
    with esteemed thanks for their previous work.
  - Drop .travis.yml; we are using Salsa now and likely would not give
    support for running on Travis CI at this point.
  [ Jelle van der Waa ]
  * Update LLVM diff for LLVM version 10.
  [ Vagrant Cascadian ]
  * Add external tool reference on openssl for GNU Guix.
- Update to version 143:
  * Add support for .p7c and .p7b certificates.
    (Closes: reproducible-builds/diffoscope#94)
  * Add "pdftotext" as a requirement to run the PDF test_metadata text. Special
    thanks to Chocimier/Piotr for the debugging work.
    (Closes: reproducible-builds/diffoscope#99)
  * Improve the documentation of FALLBACK_FILE_TYPE_HEADER_PREFIX and
    FILE_TYPE_HEADER_PREFIX to note that only the first 16 bytes are used.
- Update to version 142:
  [ Chris Lamb ]
  * Render multiline difference comments in a way to show indentation.
    (Closes: reproducible-builds/diffoscope#101)
  * Correct parsing of "./setup.py test --pytest-args ...".
  * Capitalise "Ordering differences only" in text comparison comments.
  * Don't include the JSON similarity percentage if it is 0.0%%.
  [ Ben Hutchings ]
  * Document how --exclude arguments are matched against filenames.
  [ Vagrant Cascadian ]
  * Add external tool reference for h5dump on Guix.
- Update to version 141:
  [ Chris Lamb ]
  * Dalvik .dex files can also serve as APK containers. Restrict the narrower
    identification of .dex files to files ending with this extension, and widen
    the identification of APK files to when file(1) discovers a Dalvik file.
    (Closes: deb#884095, reproducible-builds/diffoscope#28)
  * Explicitly list python3-h5py in debian/tests/control.in to ensure that we
    have this module installed during an autopkgtest run to generate the test
    fixture & regenerate debian/tests/control from debian/tests/control.in
    to match.
  * Drop unnecessary and unused assignment to "diff" variable.
  * Strip paths from the output of zipinfo(1) warnings.
    (re. reproducible-builds/diffoscope#97)
  [ Michael Osipov ]
  * Revert to using zipinfo(1) directly instead of piping input via /dev/stdin
    for BSD portability. (Closes: reproducible-builds/diffoscope#97)
  [ Jelle van der Waa ]
  * Add an external tool for h5dump on Arch.
- Update to version 140:
  * apktool 2.5.0 changed the handling of output of XML schemas, so update and
    restrict the corresponding test to match.
    (Closes: reproducible-builds/diffoscope#96)
  * Add support for Hierarchical Data Format (HD5) files.
    (Closes: reproducible-builds/diffoscope#95)
- Update to version 139:
  [ Mattia Rizzolo ]
  * Fix Build-Depends on python3-pdfminer. (Closes: deb#955645)
- Update to version 138:
  * New features & bug fixes:
  - Use dumppdf from python3-pdfminer if we do not see any other differences
    from pdftext, etc. (reproducible-builds/diffoscope#92)
  - Prevent a traceback when comparing two .rdx files directly as get_member
    will return a file even if the file is missing and not raise a KeyError
    exception; we therefore explicitly test for the existence of the file.
  * Don't allow errors within "Rscript" deserialisation to cause the entire
    operation to fail (for example if an external library cannot be loaded).
    (reproducible-builds/diffoscope#91)
  * Reporting improvements:
  - Inject the supported file formats into the package long description and
    remove any duplicate comparator descriptions when formatting.
    (#reproducible-builds/diffoscope#90)
  - Print a potentially-helpful message if the PyPDF2 module is not installed
    (#reproducible-builds/diffoscope#92)
  - Weaken "Install the X package to get a better output" claim to "... may
    produce a better output" as this is not guaranteed.
  * Code improvements:
  - Inline the RequiredToolNotFound.get_package method; only used once.
  - Drop deprecated "py36 = [..]" argument in pyproject.toml.
  - Factor out generation of comparator descriptions.
  - Add an upstream metadata file.
- Update to version 137:
  * Also extract classes2.dex, classes3.dex etc. from .apk files.
    (Closes: reproducible-builds/diffoscope#88)
  * Add generalised support for "ignoring" returncodes and move special-casing
    of returncodes in the zip comparator to this.
  * Accommodate sng returning with a UNIX exit code of 1 even if there minor
    errors in the file (discovered via #950806).
- Update to version 136:
  [ Chris Lamb ]
  * Improvements:
  - Support external build tools. (Closes: reproducible-builds/diffoscope#87)
  - Fallback to the regular .zip container format for .apk files if apktool
    is not available.
  - Clarify that "install X" in difference comment messages actually refer to
    a system/distribution package.
  - Drop the --max-report-size-child and --max-diff-block-lines-parent
    options; both deprecated and scheduled for removal in January 2018.
  * Bug fixes:
  - No longer raise a KeyError exception if we request an invalid member from
    a directory container.
  * Logging improvements:
  - Log a debug-level message if we cannot open a file as container due to a
    missing tool in order to assist diagnosing issues.
  - If we don't know the HTML output name, don't emit an enigmatic "html
    output for" message.
  - Add the current PATH environment variable to the "Normalising locale..."
    debug-level message.
  - Print the "Starting diffoscope $VERSION" line as the first line.
  - Correct a debug-level message for compare_meta calls to quote the
    arguments correctly.
  * Refactoring:
  - Add support for alternative container types for a file, allowing for
    runtime (vs import time) control of fallbacks such as adding comments.
    and append a comment to a difference if we fallback to an inferior
    container format due to missing a tool.
  - Factor-out the generation of "foo not available in path" difference
    comment messages as a helper method in the exception that represents
    them.
  * Code improvements:
  - Tidy diffoscope.main's configure method, factoring out the set of the
    Config() global out of the run_diffoscope method and inlining the
    functionality of maybe_set_limit, etc.
  - Rename diffoscope.locale module to diffoscope.environ as we are modifying
    things beyond just the locale (eg. calling tzset(), etc.)
  - Drop unused "Difference" import from the APK comparator.
  - Drop an assertion that is guaranteed by parallel "if" conditional.
  - Add a "noqa" line to avoid a false-positive flake8 "unused import"
    warning.
  - Turn down the "volume" for a recommendation in a comment.
  * Release/source-code management:
  - Add a .git-blame-ignore-revs file to improve the output of git-blame(1) by
    ignoring large changes when introducing the Black source code reformatter
    and update the CONTRIBUTING.md guide on how to optionally use it locally.
  - Convert CONTRIBUTING.rst to CONTRIBUTING.md and include it in the
    PyPI.org release.
  * Test improvements
  - Refresh and update the fixtures for the .ico tests to match the latest
    version of Imagemagick in Debian unstable.
  [ Holger Levsen ]
  * Bump Standards Version to 4.5.0, no changes needed.
  [ Marc Herbert ]
  * Search for expected keywords in the output of cbfstool tests and not a
    specific output. (Closes: reproducible-builds/diffoscope!42)
- Update to version 135:
  [ Chris Lamb ]
  * Extract resources.arsc files (as well as classes.dex) from Android .apk
    files to ensure that we at least show differences there. (Closes: deb#916359)
  * Always pass a filename with a ".zip" extension to zipnote otherwise it
    will return with an exit code of 9 and revert to a binary diff for the
    entire file.
  * Don't exhaustively output the entire HTML report when testing the
    regression for #875281; parsing the JSON and pruning the tree should be
    enough.
  * Factor out running all of our zipinfo variants into a new method and use
    this routine when comparing .apk files, thus now also displaying any
    differences exposed by bsdtar.
  * Testsuite improvements:
  - Always allow fixtures called "output*".
  - Actually test the output of the test_html_regression_875281 test.
  * Add a note to the "Contributing" page to suggest enable concurrency when
    running the tests locally.
  [ Marc Herbert ]
  * Fix a misplaced debug "Loading diff from stdin" logging message.
  * Add new "Testing" section to CONTRIBUTING.rst.
- Update to version 134:
  [ Chris Lamb ]
  * Ensure that autopkgtests are run with our pyproject.toml present for the
    correct "black" source code formatter settings. (Closes: deb#945993)
  * Tidy some unnecessary boolean logic in the ISO9660 tests.
  * Rename the "text_option_with_stdiout" to "text_option_with_stdout".
  * Include the libarchive file listing for ISO images to ensure that
    timestamps (not just dates) are visible in any difference.
    (Closes: reproducible-builds/diffoscope#81)
  [ Eli Schwartz ]
  * Fix an exception in the progressbar handler.
  [ Vagrant Cascadian ]
  * Add an external tool reference for zstd on GNU Guix.
- Update to version 133:
  * Correct the substitution/filtering of paths in ELF output to avoid
    unnecessary differences depending on the path name provided on the
    commandline. (Closes: deb#945572)
  * Silence/correct a SyntaxWarning message due to incorrectly comparing an
    integer by identity (is) over equality (==). (Closes: deb#945531)
- Update to version 132:
  * Allow all possible .zip variations to return with non-zero exit codes, not
    just known types we can explicitly identify (eg. Java .jmod and .jar
    files). (Closes: reproducible-builds/diffoscope#78)
  * Also permit UTF-8 encoded .dsc and .changes files.
    (Re: reproducible-builds/diffoscope#78)
  * Rework a long string of "or" statements into a loop with a "break".
- Update to version 131:
  * Clarify in the HTML and text outputs that the limits are per output format,
    not global. (Closes: deb#944882, reproducible-builds/diffoscope#76)
  - Bump the previous "max_page_size" limit from 400 kB to 4 MB.
  * Update an Android manifest test to reflect that parsed XML attributes are
    returned in a sorted or otherwise novel manner under Python 3.8.
  * Update code to reflect version 19.10b0 of the black source code
    reformatter and don't run our self-test for versions earlier than this as
    it will generate different results and thus fail.
  * Limit .dsc and .buildinfo matching; don't attempt to compare them as
    ELF sections or similar. (Closes: reproducible-builds/diffoscope#77)
  * Add a comment that the text_ascii{1,2} test fixture files are used in
    multiple places so are not trivial to generate on the fly.
- Update to version 130:
  [ Chris Lamb ]
  * debian/tests/basic-command-line:
    Move from deprecated ADTTMP to AUTOPKGTEST_TMP.
  * Correct the matching of R .rds files by also detecting newer versions
    of this file format.
  * Drop unused BASE_DIR global in the tests.
  * Try and ensure that new test data files are generated dynamically, ie.
    at least no new ones are added without "good" reasons.
  * Truncate the tcpdump expected diff to 8KB (from ~600KB).
  * Refresh OCaml test fixtures to support OCaml >= 4.08.1.  Closes: deb#944709
  * Correct reference to the ".rdx" extension in a comment.
  * Update XML test for Python 3.8+.
  * Don't use line-base dbuffering when communucating with subprocesses
    in binary mode. (Closes: reproducible-builds/diffoscope#75)
  [ Jelle van der Waa ]
  * Add support for comparing .zst files are created by zstd.
    (Closes: reproducible-builds/diffoscope!34)
- Update to version 129:
  * Call R's "deparse" function to ensure that we do not error out and revert
    to a binary diff when processing .rdb files with internal "vector" types as
    they do not automatically coerce to strings.
  * Add the ability to pass Python bytestrings to external commands and
    pass our long script to parse R .rdb files using this new method over a
    long command-line argument
  * Use Rscript's --vanilla option over --no-environ as this also enables
  - -no-save, --no-restore, --no-site-file and --no-init-file.
  * Improve command-line error messages:
  - Split out formatting into a separate utility function.
  - Truncate very long lines when displaying them as an external source
    of data.
  - When printing an error from a command, format the command for the user.
  * Use "exit code" over "return code" when referring to UNIX error codes in
    displayed differences.
- Update to version 128:
  * Query the container for the full path of the parallel R .rdx file for a
    .rdb file as well as looking in the same directory. This ensures that
    comparing two .deb/.changes files shows a varying path introduced in
    version 127.
- Update to version 127:
  [ Chris Lamb ]
  * Move build-dependency on python-argcomplete to the Python 3.x version to
    facilitate Python 2.x removal. (Closes: deb#942967)
  * Overhaul the handling of GNU R .rdb files:
  - Rework and refactor the handling of .rdb files specifically with respect
    to locating the parallel .rdx file prior to inspecting the file to ensure
    that we do not add files to the user's filesystem in the case of directly
    comparing two .rdb files or, worse, overwriting a file in is place.
  - Use a ("""-formatted) docstring for our internal R script to dump
    variables.
  - Mask/hide standard errors; R will often produce noisy output that is not
    useful to us.
  - Don't include a useless and misleading "NULL".
  - Include all R object names are displayed, including ones beginning with a
    fullstop (".").
  - Sort package fields when dumping data for output stability.
  - Format package contents as "foo = bar" rather than using ugly and
    misleading brackets.
  - Include the object's type when dumping package contents.
  - Never read the site or user's R location environment configuration to
    ensure output stability.
  - Expose absolute paths in the semantic/human-readable output, preventing
    falling back to a useless hexdump.
  * Improve the formatting of command lines:
  - Ensure newlines and other metacharacters appear escaped as "\n", etc.
  - Use the newline (etc.) escaped version of the commandline being executed
    in logging/debug output.
  - When displaying standard error, ensure use the escaped version too.
  * Add support for easily masking the standard error of commands and use this
    in the ffprobe comparator.
  * To match the libarchive container, raise a KeyError exception if we request
    an invalid member from a directory container.
  * Correct string representation output in the traceback when we cannot locate
    a specific item in a container.
  [ Mattia Rizzolo ]
  * Run Debian autopkgtests against all Python versions.
- Update to version 126:
  [ Chris Lamb ]
  * Track and report on missing Python modules.
    (Closes: reproducible-builds/diffoscope#72)
  * Drop some unnecessary control flow.
  * Drop explicit inheriting from 'object' class; unnecessary in Python 3.
  * Bump Standards-Version to 4.4.1.
  [ Mattia Rizzolo ]
  * Exit with 2 instead of 1 in case of no disk space.
- Update to version 125:
  * The test_libmix_differences ELF test requires xxd. (Closes: deb#940645)
- Update to version 124:
  [ Chris Lamb ]
  * Also conditionally skip the identification and "no differences" tests as we
    require the Ocaml compiler to be present when building the test files
    themselves. (Closes: deb#940471)
  [ Mattia Rizzolo ]
  * Permit all sorts of version suffixes when checking the Debian package
    version matches setup.py, not just for backports. (Closes: deb#939387)
  [ Vagrant Cascadian ]
  * Add external tools on GNU Guix for odt2txt, sng and pgpdump.
  [ Marc Herbert ]
  * Remove StaticLibFile in the ELF comparator -- ArFile.compare_details() is
    superior. (Closes: reproducible-builds/diffoscope#64)
- Update to version 123:
  [ Chris Lamb ]
  * Build OCaml test input files on-demand rather than shipping them with the
    package in order to prevent test failures with OCaml 4.08.
    (Closes: deb#939386)
  * Update test skipping messages:
  - When skipping tests due to the lack of installed tool, print the package
    that may provide it.
  - Update "requires foo module" messages to clarify that they are regarding
    Python modules, not packages.
  * Rebuild the test squashfs images to exclude the character device as they
    requires root or fakeroot to extract. (reproducible-builds/diffoscope#65)
  * Remove accidentally-committed test fixture generation code from tests.
  * Set long_description_content_type to 'text/x-rst' in setup.py to appease
    the PyPI.org linter.
  [ Mattia Rizzolo ]
  * Don't crash when the progress is requested but the Python module is
    missing. (Closes: deb#939085)
  [ Vagrant Cascadian ]
  * Add external tools for gifbuild, javap and kbxutil in GNU Guix.
  [ Marc Herbert ]
  * In the cbfs tests, add a "Comp" column test to support Coreboot
    utils > 4.6.
- Update to version 122:
  [ Chris Lamb ]
  * Apply patch from László Böszörményi to update the squashfs test output and
    bump the required version for the test itself. (Closes: deb#935684)
  * Skip calls to unsquashfs when we are not root or fakeroot.
    (Re: reproducible-builds/diffoscope#63)
  * Include either standard error or standard output (and not just the latter)
    if/when an external command fails.
  * Fix a few unicode/bytes issues:
  - Avoid a possible traceback caused by a str/bytes confusion when handling
    the output of failing external commands.
  - Ensure that all of our artificially-created subprocess.CalledProcessError
    instances have `output` instances that are bytes objects, not str.
  * Improve debugging output:
  * Add the containing module name to the (eg.) "Using StaticLibFile for ..."
  * Improve and condense output when creating our Comparator object types.
  * Correct a reference to `parser.diff` as `diff` in this context is a Python
    function in the module, not the actual output returned from diff(1).
  * Add the "wabt" Debian package to the test dependencies so that we run the
    wasm tests.
  [ Mattia Rizzolo ]
  * Now that we test-require wabt, expect that its tools to be available during
    autopkgtests.
- Update to version 121:
  * Don't fallback to a (useless) raw hexdump when readelf(1) reports an minor
    issue in a section in an ELF binary. For example, when the "frames" section
    is of the "NOBITS" type, its contents are apparently "unreliable" and thus
    readelf(1) exits with a returncode of 1. (Closes: deb#849407, #931962)
  * Add support to Difference.from_command_exc and friends to optionally ignore
    specified returncodes from the called program and treat them as "no"
    difference.
  * Simplify the parsing of the optional "command_args" argument to the
    from_command and from_command_exc methods in the Difference class.
- Update to version 120:
  * No-change sourceful after accidentally uploading binaries in order to
    migration to testing.
- Update to version 119:
  [ Chris Lamb ]
  * If a command fails to execute but does not print anything to standard
    error, try and include the first line of standard output in the message we
    include in the diff. This was motivated by readelf(1) returning its error
    messages on stdout. (Closes: deb#931963)
  * Add support for Java ".jmod" modules. Not all versions of file(1) support
    detection of Jmod files yet, so we perform a manual comparison instead.
    (Closes: deb#933308)
  * Re-add "return code" noun to "Command `foo` exited with X" error messages.
  * Factor out the ability to ignore the exit codes of "zipinfo" and
    "zipinfo -v" in the presence of non-standard headers.
  * Only override the exit code from our special-cased calls to zipinfo(1) if
    they are 1 or 2 to avoid potentially masking real errors.
  * Also add missing textual description entries for ZipFile and
    MozillaZipFile file types.
  * Skip extra newline in "Output:\n<none>".
  * Cease ignoring test failures in stable-backports.
  * Bump debhelper compat level to 12.
  [ Marc Herbert ]
  * Catch failures to disassemble and rescue all other differences.
    (Closes: reproducible-builds/diffoscope!29)
- Update to version 118:
  * Don't fail in autopkgtests when, for example, we do not have sufficiently
    newer or older version of file. (Closes: deb#931881)
  * Also include python3-tlsh in test dependencies.
  * Tidy handling of DIFFOSCOPE_FAIL_TESTS_ON_MISSING_TOOLS:
  - Merge two previously-overlapping environment variables.
  - Use repr(..)-style output when printing test status.
  - Add some explicit return values to appease pylint.
- Update to version 117:
  [ Chris Lamb ]
  * Add support for file 5.37. Thanks again to Christoph Biedl for the heads-up
    in advance. (Closes: reproducible-builds/diffoscope/#57)
  * Apply patch from Gianfranco Costamagna to fix autopkgtest failures in
    Debian. (Closes: deb#931709)
  [ Holger Levsen ]
  * debian/control: Bump Standards-Version to 4.4.0.
- Update to version 116:
  [ Chris Lamb ]
  * Upload to unstable after the release of Debian "buster".
  * README.rst & manual page generation:
  - Strip out manpage-only parts of the README rather than using "only"
    reStructuredText directives in order to support the demands of the latest
    PyPI website.
  - Use "real" reStructuredText comments instead of using the "raw" directive.
  * Dockerfile:
  - Build the Docker image from the current Git checkout, not the Debian
    archive. (reproducible-builds/diffoscope#56)
  - Use the ENTRYPOINT directive with the JSON syntax instead so we pass all
    arguments to the underlying diffoscope executable.
  * Document that run_diffoscope should not be considered a stable API.
  [ Mattia Rizzolo ]
  * Rename a test function to prevent shadowing a previous one with the
    same name.
  * Add ffmpeg to the list of Debian build-dependencies for the testsuite.
  [ Vagrant Cascadian ]
  * Add support for known external tools in GNU Guix.
- Update to version 115):
  [ Chris Lamb ]
  * Fix execution of symbolic links that point to the "bin/diffoscope" entry
    point by fully resolving the location.
  * Add a Dockerfile.
  * Update contributing messages with instructions regarding the Docker image.
  [ Mattia Rizzolo ]
  * tests:
    + Allow specifying which tools are known missing using
    DIFFOSCOPE_TESTS_MISSING_TOOLS, to override a _FAIL_ON_MISSING_TOOLS.
    + With DIFFOSCOPE_TESTS_FAIL_ON_MISSING_TOOLS=1, actually fail only tests
    that are missing the required tools.
  * debian:
    + Add black to the test dependencies.
    + Enforce the "fail on missing tools" only when testing with all the
    recommended packages.
    + Ack some missing tools during autopkgtest.
    + Reinstate oggvideotools and procyon-decompiler test dependencies,
    now that are not buggy anymore.
- Update to version 114):
  [ Chris Lamb ]
  * Add support for GnuPG "keybox" files. Thanks to Daniel Kahn Gillmor for the
    suggestion. (Closes: deb#871244, reproducible-builds/diffoscope#23)
  * Always warn if tlsh module is not available (not just if a specific
    fuzziness threshold is specified) to match the epilog of the --help output.
    This prevents missing support for file rename detection.
    (Closes: deb#888237, reproducible-builds/diffoscope#29)
  * Treat missing tools on Debian autopkgtests as individual test failures by
    checking whether a new DIFFOSCOPE_TESTS_FAIL_ON_MISSING_TOOLS environment
    variable is exported. (Closes: deb#905885, reproducible-builds/diffoscope#35)
  * Require that "-" is explicitly specified to read a single diff from
    standard input to avoid non-intuitive behaviour when diffoscope is called
    without any arguments. (Closes: reproducible-builds/diffoscope#54)
  * Make --use-dbgsym a ternary operator to make it easier to totally disable.
    Thanks to Mattia Rizzolo for the suggestion.
  * Consolidate on "e" as the aliased exception name.
  [ Milena Boselli Rosa ]
  * Various fixes to the HTML markup to prevent validation warnings/errors:
  - Prevent empty values for the "name" attribute name on HTML anchor tags,
    and add an "id" to its parent "div" container.
  - Fix "table column x established by element 'col' has no cells beginning
    in it" warnings.
  - Fix "Text run is not in Unicode Normalization Form C".
  - Remove the "type" HTML attribute from <style> elements.
  [ Vibhu ]
  * Fail more gracefully when running out of diskspace. (Closes: deb#874582)
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add keyring to the spec file
- Use python macros
- Run fdupes
- Execute tests, but always make them pass 7 currently fail
* Fri Apr  5 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- update to version 113
  * better handle missing helpers at runtime
  * improved handling of zip, elf, pdf, wasm(WebAssembly) formats
  * improved output readability
* Tue Nov 13 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
  * update to new version 105:
  * tests:
    + Prevent test failures when running under stretch-backports by checking
    the ocaml version number.  Closes: deb#911846
  * debian: Reinstate apktool Build-Depends and Test-Depends.
  * Fix some flake8 and deprecation warnings.
  * comparators/pcap:
    + Fix recognition with the upcoming file(1) 5.35.  Closes: deb#912756
    Thanks to Christoph Biedl for the heads-up in advance.
  * Add a new command line flag --list-missing-tools.  MR: !14
  * update to new version 104:
  * comparators:
    + macho: Prevent a traceback if the filename cannot be found on the line.
    Closes: deb#910540
    + ocaml New comparator OCaml files using ocamlobjinfo.  Closes: deb#910542
    + pdf: Add support for comparing metadata using PyPDF2.  Closes: deb#911446
  * debian/tests/control.in: Add note on how to regenerate this file.
  * d/control:
    + Build-Depend on linux-image-amd64 [amd64] to allow squashfs tests to run.
    + Add a Build-Conflicts against graphicsmagick-imagemagick-compat.
    See: #910652
  * Move the list of optional python packages from d/rules into setup.py, and
    have dh_python3 check the generated requires.txt.
  * Also add the optional python modules to the autopkgtest dependencies.
  * Temporarily drop Build-Depends and Test-Depends on apktool and
    oggvideotools, as they are not available in buster at the moment.
  * comparators:
    + java:
  - Rename the tool procyon-decompiler to procyon.
  - Properly fall back from procyon to javap also when procyon exists
    but doesn't return any output.
  * Declare in setup.py that diffoscope is good to go with Python 3.7.
  * comparators:
    + fsimage: Handle FAT filesystems.  MR: !13
  * update to new version 103:
  * In Debian, list liblz4-tool as an alternative to the lz4 package.
    stretch only has the former.
  * Strip trailing whitespace from ssconvert(1) output to support
    gnumeric 1.12.43.
  * update to new version 102:
  * Fix tests under colord >= 1.4.3.  Closes: deb#908900
  * Add an "Add a comparator" section in CONTRIBUTING.  MR: !9
  * debian: Use the new debhelper-compat(=11) build dep and drop d/compat.
  * comparators/json: Try fuzzy matching for non-text files too.
    This avoids loading very large file just to discover they aren't JSON.
    Closes: deb#909122
  * update to new version 101:
  * Fix testsuite under LLVM >= 7.0. (Closes: deb#908074)
  * Substvar generation:
  - Ensure Debian substvar generation is deterministic regardless of
    installed packages. (Closes: deb#908072)
  - Clarify distinction between tools (eg. gpg) and packages (eg. gnupg) when
    generating Debian substvars.
  - Revert updating generated debian/tests/control made in diffoscope 100.
  * Disable binwalk's own user configuration for predictable results and to
    ensure it does not create unnecessary directories. (Closes: deb#903444)
  * Ensure we return "bytes" objects from Command.filter to avoid a
    "TypeError: Unicode-objects must be encoded before hashing" traceback.
  * Don't print GPG output in diffoscope.changes.
  * update to new version 100:
  * Correct matching of .deb archive members. (Closes: deb#903565)
  * Support .deb archives that contain an uncompressed control.tar and data.tar
    Thanks to Roderich Schupp <roderich.schupp@gmail.com>.
    (Closes: deb#903391, #903401)
  * Wrap jsondiff calls with try-except to prevent fatal errors.
    (Closes: deb#903447, #903449)
  * Don't include the filename in llvm-bcanalyzer results. (Closes: deb#905598)
  * Update generated debian/tests/control.
  * Bump Standards-Version to 4.2.1.
  * Avoid line eraser error on dumb terminals. (Closes: deb#906967)
  * Correct spelling of ereser to eraser.
  * On Debian, do not require apktool on ppc64el and s390x, ogvideotools on
    s390x and fp-utils on ppc64el and s390x as they are not installable there.
  * Explicitly add `file` to the dependencies of autopkgtest to have the tests
    triggered whenever `file` changes
  * Handle errors with encrypted archive files. (Closes: deb#904685)
  * update to new version 99:
  * Add lz4 comparator.  Closes: deb#901548; !4
  * Clear the progress bar after completion.  Closes: deb#901758
    Handle terminals that do not support erasing the line by filling the
    terminal with spaces.  Ignore output devices that are not terminals.
  * Do not delete the current terminal line for every progress bar update.
    The erasure was also causing the progress bar to flicker.
  * Add a gitlab CI script.  !8
  * tempfiles:
    + Set the base directory only if the caller didn't specify one already.
    + Do not append '_diffoscope' to the temporary file names, as they are now
    all in their namespaced directory already.
    + Empty the list of known tempfiles after removing them.  Closes: deb#902709
  * external_tools:
    + Fix package name, s/xmlutils/xmlbeans/.
  * tests/test_tools: fix test if /sbin contains a directory.  MR: !2
    Thanks to Chris Lamb <lamby@debian.org> for the patch.
  * logging:
    + Move the computation of the terminal line eraser into logging.py
    + Always clean the line before printing a log message
  * main:
    + Clean the terminal line before printing a traceback.
    + Be sure to print 'Keyboard Interrupt' if that happens.
  * comparators:
    + Do not shadow the original import errors.  MR: !7
  * d/control:
    + Bump Standards-Version to 4.1.5, no changes needed.
    + Add Build-Dependency on procyon-decompiler, to run the tests.
  * d/tests:
    + Autogenerate d/tests/control with all the recommends listed as
    dependencies, so autopkgtest is appropriately triggered whenever one of
    those packages changes.  Closes: deb#902920
  * comparators.utils:libarchive:
    + Add compatibility code for python-libarchive >= 2.8.  MR: !6
  * update to new version 98:
  * Fix compatibility with Python 3.7. (Closes: deb#902650)
  * update to new version 97:
  * Create all temporary directories within a top-level dir. (Closes: deb#902627)
  * tests/conftest.py: Fix compatibility with pytest 3.6.2-1, currently in
    Debian experimental.
  * update to new version 96:
  * Drop dependency on pdftk as it relies on GCJ, relying on the pdftotext
    fallback. (Closes: deb#893702)
  * Change the "No file format specific differences found inside, yet data
    differs" message to be clearer that diffoscope "knows" about this file
    format yet could not be helpful in this case.
  * Don't append a rather useless "(data)" suffix from file(1).
  * Comply with a number of PEP8 recommendations:
  - E226 - Add missing whitespaces around operators.
  - E241 - Fix extraneous whitespaces around keywords.
  - E251 - Remove whitespace around parameter '=' signs.
  - E302 - Add missing 2 blank lines.
  - E501 - Try to make lines fit to length.
  - E502 - Remove extraneous escape of newline.
  - E731 - Don't assign lambda expressions.
  - E121, E122, E126, E128 - Fix badly indented lines.
  * Add merge request details to contributing documentation.
  * update to new version 95:
  * tests:
    + test_binary: Don't capture unused output from subprocess.
    + test_git: Fix test failure on FreeBSD.  Closes: deb#872826
    Thanks to Ximin Luo <infinity0@debian.org> for the initial patch
  * Fix handling of filesnames with non-unicode chars.  Closes: deb#898022
  * diff: Use bytes as much as possible, to prevent possible encoding issues.
  * d/control: Make the dependency on python3-distutils an alternative on the
    previous versions of libpython3.*-stdlib that used to ship it.
    Closes: deb#898683
  * d/watch: Update URL to the new archive.
  * The Git repository has been migrated to salsa, update all the references.
  * Drop extra whitespace in supported file format output.
  * update to new version 94:
  * Update tests to prevent FTBFS under file 5.33. (Closes: deb#897099)
  * Remove all __pycache__ directories to avoid source-contains-empty-directory
    Lintian warning.
  * Remove unused test1.txt test data file.
  * Bump Standards-Version to 4.1.4.
  * Add gnumeric to the list of ArchLinux tools.
  * Sort the Debian dependencies.
  * update to new version 93:
  * Only append the file formats if --help is passed, otherwise we spam
    [#]debian-reproducible-changes et al. (re. #893443)
  * doc/Makefile: Reinstate accidental version parsing change; my sed call
    was over-eager.
  * update to new version 92:
  * New features:
  - Show the list of supported file types in the manual and --help output. We
    can copy-paste this into the website, etc.. Thanks to Jonathan Dowland
    for the suggestion. (Closes: deb#893443)
  - Add support for comparing Gnumeric spreadsheets. (Closes: deb#893311)
  * Bug fixes:
  - Additionally extract the classes.dex file from .apk files; apktool does
    not do this by default which was preventing us from recursing into it to
    find differences. Thanks to Hans-Christoph Steiner for the report.
    (Closes: deb#890904)
  - Recursively reset the permissions of temporary directories prior to
    deletion to ensure that non-writable permissions such as 0555 are removed
    and do not cause a traceback. (Closes: deb#891363)
  - Support the case where the python3-xattr package is installed but
    python3-pyxattr is not. Based on an patch by Doug Freed; thanks!
    (Closes: deb#892240)
  - Update Java tests for openjdk-9. (Closes: deb#893183)
  * Output:
  - Print a nicer error message if you only specify one file to compare.
  - Don't show progress bar if we passed --debug as it just gets in the way.
  * Code tidying:
  - Avoid some necessary indentation around unconditional control flow.
  - Tidy unnecessary assignments.
  - Move the documentation for maybe_decode into a docstring on the method
    itself.
  - Import LooseVersion as LooseVersion.
  - Use more Pythonic `old_level` variable names (over `oldLabel`) and avoid
    using ambiguous `l` variable names.
  - Add whitespace around operators and ensure 4-line indentation throughout.
  * debian/*:
  - Move DOS/MBR check into the testsuite.
  - Add explicit runtime dependency on python3-distutils as it was dropped in
    src:python3.6 3.6.5~rc1-2.
  * Misc:
  - Clarify that the Reproducible Builds project is not just about Debian.
  - Drop executable bit on doc/Makefile.
  - Use our bin/diffoscope wrapper in manpage generation to ensure we are
    using the local version of diffoscope.
  * Update terminology used in docs about exclusion options. Thanks to Paul
    Wise for the idea. (Closes: deb#893324)
  * Don't try to decode a string in comparators.utils.file. (Closes: deb#891903)
  * Save a bunch of system calls by resetting tempfile permissions when
    we actually need to do it.
  * update to new version 91:
  * d/clean: Remove .cache/.
  * diff: Wrap long regular expression for improved readability.
  * comparators.json: Fix UnicodeDecodeError with a non-UTF8 locale.
  * d/copyright: Update for the new year.
  * d/control: Bump Standards-Version to 4.1.3, no changes needed.
  * tests/android:
    + Skip tests involving abootimg on BE archs (see #725729).
  * diffoscope.diff: Document feeders.  Closes: deb#863880
  * Optimize the common case of feeders.  Closes: deb#863879
  * {tempfiles, utils.archive}: catch possible FileNotFoundError.
  * comparators.java: add support for procyon-decompiler.  Closes: deb#849386
  * {command, feeders, diff}: replaces subprocess.Popen() by .run().
    This is done in preparation for work on multiprocessing (#842837).
    + {command, zip, feeders}: replaces .wait by the new .returncode property.
    + comparators.utils.command: replaces .stderr_content by .stderr.
  * tests:
    + test_progress: fix test case for some broken versions of
    python-progressbar.  Closes: deb#877726
    + utils.tools: add support for modules on skip_unless* annotations.
  * comparators:
    + utils/compare:
  - Show extended filesystem metadata even when directly comparing two
    files, not just when we specify two directories.  Closes: deb#888402
    + macho:
  - If the If the LLVM disassembler does not work, try the
    internal one.  Closes: deb#886736
  - Always strip the filename, not just when by itself.
    + json:
  - Do some cheap fuzzy parsing to detect JSON files not named .json.
  - Also match unicode JSON files.
  - Optionally compare JSONs with the jsondiff module.  Closes: deb#888112
    + directory:
  - Report differences in extended file attributes when comparing files.
    Closes: deb#888401
    + xsb:
  - Add support for comparing XMLBeans binary schemas.
    + barkeley_db:
  - Add support for comparing Berkeley DB files.  Closes: deb#890528
  * Misc code cleaup.
  * tests:
    + comparators.test_elf: Return '0' if we can't parse the readelf
    version number.  Closes: deb#886963
  * debian:
    + Explicitly build-depend and recommend e2fsprogs.  Closes: deb#887180
  * Partially revert the changes done for #888402 to maintain the current.
    behaviour of --exclude-directory-metadata.
  * Refactor how the configuration is loaded:
    + Move the defaults into a Config.reset() method.
    + reset() the configuration at the end of main(), to help the testsuite.
  * update to new version 90:
  * tests:
    + comparators/test_rlib: Fix tests for llvm >= 5.0.  Closes: deb#877727
    + Skip some tests if 'xz' is not present.
  * update to new version 89:
  * comparators:
    + elf:
  - Add fallbacks to elf code section disassembly.  Closes: deb#879003
    + utils/libarchive:
  - Extract libarchive members with the file extension.
  * Auto-generate manpage using help2man, so it's no longer out-of-date.
  * difference:
    + Add a Difference.from_command_exc() to help distinguish excluded
    commands from commands returning an empty diff.
  * comparators:
    + utils/command:
  - Replace the feed_stdin() feeder into the simpler stdin() function,
    which provides (if needed) a simple file opject instead of a feeder.
    + utils/container:
  - Add a perform_fuzzy_matching() method (wrapping the already existing
    method) so that comparators can easily override it.
    + deb:
  - Loose matching for .deb archive members, so it's possible to e.g.
    compare deb with different control.tar.{gz,xz}.  Closes: deb#881937
    + elf:
  - Improve disassembly fallbacks with Difference.from_command_exc().
    + png:
  - Cater for the feed_stdin() removal.
    + zip:
  - Run zipinfo on /dev/stdin instead of a variable path to avoid including
    the temporary file name in the output.  Closes: deb#879011
  - Cater for the feed_stdin() removal.
  * presenters/formats:
    + Allow non-text formats to output an empty diff.
  * debian/clean:
    + Remove the egg file when cleaning.
  * comparators:
    + utils/file:
  - Handle case where a file to be "fuzzy" matched does not contain enough
    entropy despite being over 512 bytes.  Closes: deb#882981
    + android:
  - Add support for Android ROM boot.img introspection.  Closes: deb#884557
    + symlink:
  - Make cleanup of placeholders idempotent.
  * tests:
    + utils/tools:
  - Add a skip_if_tool_version_is() function.
    + elf:
  - Skip some tests if readelf is version '2.29', where its behaviour
    was accidentally changed to exit with code 1 when it previously
    didn't.  Closes: deb#877728
  * debian/control: Bump Standards-Version to 4.1.2.  No changes required.
  * debian/control: Set Rules-Requires-Root: no.
  * Bump Debhelper compat version to 11.
  * update to new version 88:
  * Bump standards version to 4.1.1, no changes needed.
  * tests/comparators:
    + dtb: compatibility with version 1.4.5.  Closes: deb#880279
  * comparators:
    + binwalk: improve names in output of "internal" members.  Closes: deb#877525
    + Omit misleading "any of" prefix when only complaining about one module
    in ImportError messages.
  * Don't crash on malformed md5sums files.  Closes: deb#877473
  * tests/comparators:
    + ps: ps2ascii > 9.21 now varies on timezone, so skip this test for now.
    + dtby: only parse the version number, not any "-dirty" suffix.
  * debian/watch: use HTTPS URI.
  * comparators:
    + utils/file: diff container metadata centrally.  Closes: deb#797759
    This fixes a last remaining bug in fuzzy-matching across containers.
    + Fix all the affected comparators after the above change.
  * update to new version 87:
  * comparators:
    + utils:
  - compare: fix comparison between container types.
  - container: add get_path_name() method, aiming at preventing hitting
    OS' max filename length.
    + gzip: replace dest_path generation with self.get_path_name().
    + bzip2: replace dest_path generation with self.get_path_name().
  * tests:
    + presenters:
  - skip html_visuals test if 'sng' binary is not available.
    + comparators:
  - test_cointainers: new tests to test cross-container comparisons.
  - add test_containers.py.
  * comparators:
    + utils:
  - file: correct reference to path_apparent_size.
    + fonts: loosen matching of file(1)'s output to ensure we correctly also
    match TTF files under file 5.32.
    + binwalk:
  - new comparator to deal with (e.g.) concatenated CPIO archives using
    the new optional python module 'binwalk'.  Closes: deb#820631
  * diffoscope.diff: Correct reference to self.buf.
  * debian/rules: run flake8 during the tests, and fail the build in case the
    "underfined name" flake8's check fails.
  * tests/comparators:
    + test_cpio: check we identify all CPIO fixtures.
  * main:
    + print a debugging message if we are reading diff from stdin.
  * presenters:
    + html: use logging.py's lazy argument interpolation.
  * debian/control: bump Standards-Version to 4.1.0.
  * Code style improvements across all of the codebase.
  * debian/changelog: retroactively close a bug in an old changelog entry.
  * setup.py: add a check to prevent people from installing diffoscope under
    python < 3.5 (i.e. python2) and give them a usable error message otherwise.
  * Code style improvements across all of the codebase.
  * comparators:
    +  add a fallback_recognizes() method to work around file(1)'s bug #876316.
    Closes: deb#875282
    + add a --force-details flag for debugging.
    + deb:
  - if --force-details then don't skip files with identical md5sums either.
  * presenters:
    + html:
  - prune all descendants properly.  Closes: deb#875281
  - don't show pointer-cursor when jquery is disabled.
  * config:
    + force-set a value if it must be less than another, and it was not set on
    purpose.  Closes: deb#875451
  * readers: convert bytes to str in the right place.
  * diff: use diff_split_lines everywhere.
  * difference:
    + in fmap/map_lines, don't forget about self._visuals.
    + also copy self._comment properly, compare self._visuals in equals().
  * tests/comparators:
    + test_deb: make test_md5sums less brittle.
  * update to new version 86:
  * tests:
    + binary: skip a test if the 'distro' module is not available.
    + iso9660: avoid an overly-catching exception.
  * debian/copyright: coalesce some file paragraphs and update information.
  * tests:
    + iso9660: support both cdrtools' genisoimage's versions of isoinfo.
  * comparators:
    + xml: Use ``name`` attribute over ``path`` to avoid leaking comparison
    full path in output.
  * Tidy diffoscope.progress a little.
  * Add a --tool-prefix-binutils CLI flag.  Closes: deb#869868
  * On non-GNU systems, prefer some tools that start with "g".  Closes: deb#871029
  * presenters:
    + html:
  - Don't traverse children whose parents were already limited.
    Closes: deb#871413
  * diffoscope.progress:
    + Support the new fork of python-progressbar.  Closes: deb#873157
* Wed Aug  2 2017 sleep_walker@opensuse.org
- Update to 85:
  see GIT log for full list of changes
* Tue Mar 14 2017 kgronlund@suse.com
- Update to 78:
  * Catch bad JSON errors on Python pre-3.5.  Closes: deb#855233
  * Correct logic of module_exists, ensuring we correctly skip in case of
    modules containing a dot in their name.  Closes: deb#854745
  * No need to track archive directory locations.
  * Add --exclude option.  Closes: deb#854783
  * When extracting archives, try to keep directory sizes small.
  * Extract archive members using an auto-incrementing integer, avoiding the
    need to sanitise filenames and avoiding writes to arbitrary locations.
    (Closes: deb#854723 * CVE-2017-0359)
  * Fix autopkgtest failures when Recommends are not installed.
    (Closes: deb#854593)
  * Specify <html lang="en"> in HTML output. (re. #849411)
  * Add a machine-readable JSON output format. (Closes: deb#850791)
  * Show results from debugging packages last. (Closes: deb#820427)
  * Add a --max-text-report-size option. (Closes: deb#851147)
    Clean all temp files in signal handler thread instead of attempting to
    bubble exception back to the main thread. (Closes: deb#852013)
  * Prevent FTBFS by loading fixtures as UTF-8 in case surrounding terminal
    is not Unicode-aware. (Closes: deb#852926)
  * Fix errors when comparing directories with non-directories.
    (Closes: deb#835641)
  * Fix behaviour of setting report maximums to zero (ie. no limits)
  * diffoscope.diff: Improve FIFO writing robustness.
  * haskell: Properly extract version from interface files.
  * Add markdown output support.  Closes: deb#848141
  * Add RestructuredText output format.
  * Improve --help output.  Closes: deb#852015
  * Don't blow up if directory containing ELF debug symbols already exists.
    (Closes: deb#850807)
  * Fix .APK extration when provided with absolute filenames.
    (Closes: deb#850485)
  * Support comparing .ico files using img2txt. (Closes: deb#850730)
  * comparators.utils.file: If we don't have an archive-extraction tool (eg.
    apktool), don't blow up when attempting to unpack it.
  * Include magic file type when we know the file format but can't find
    file-specific details. (Closes: deb#850850)
  * Ensure fake "APK metadata" file appears first, fixing non-deterministic
    tests/output.
  * Correctly escape value of href="" elements (re. #849411)
  * comparators/device: don't crash when comparing a non-device against a
    device (Closes: deb#850055)
  * Remove archive name from apktool.yml and rename it. (Closes: deb#850501)
  * Zipinfo included in APK files comparison. (Closes: deb#850502)
  * Add some tests for APK comparator.
  * Add image metadata comparison. (Closes: deb#849395)
  * Ensure imagemagick version is new enough for image metadata tests.
  * Extend .apk recognition regex to also match zip archives (Closes: deb#849638)
  * Update dex_expected_diffs and test requirement to ensure test compatibility
    with enjarify >= 1.0.3. (Closes: deb#849142)
  * Add detection of order-only difference in plain text format.
    (Closes: deb#848049)
  * Fix sqlite3 magic recognition when using file >= 5.27. (Closes: deb#830434)
  * Add argument completion feature to diffoscope. (Closes: deb#826711)
  * Improve message when data differs. (Closes: deb#827981)
  * Clarify the input arguments. (Closes: deb#826894)
  * Fix maybe_decode() so that it actually works.
* Thu Jun 23 2016 sleep_walker@opensuse.org
- update to 54:
  * In the directory comparator, fall back to current directory instead of
    empty name. (Closes: deb#820624)
  * Improve deb(5) support. (Closes: deb#818414)
  * debian/control: add myself to Uploaders.
  * Clean up temporary debuglink files.
  * Fix FileNotFoundError with broken symlinks. (Closes: deb#818856)
  * Decode Md5sumsFile in utf-8. (Closes: deb#823874)
  * Always suffix temporary files with '_diffoscope'.
  * Rewrite sanity check for the version to always run every time debian/rules
    is invoked, not only during a binary build.
  * Add FreeBSD packages for required tools.
  * Add README.rst to MANIFEST.in.
  * debian/gbp.conf: add a conf to have gbp tag the releases how we like them.
  * Drop transitional debbindiff package.
  * debian/control: Drop XS-Prefix from Testsuite: field, thanks lintian.
  * Mention --max-report-size only once in the manpage. (Closes: deb#819956)
  * Fix typo in documentation.
  * Bump Standards-Version to 3.9.8, no changes required.
  * Let objdump demangle symbols for better readability.
  * Install bin/diffoscope instead of auto-generated script. (Closes: deb#821777)
  * Team upload.
  * Re-upload, the last uploaded tarball was broken, missing test files.
  * Remove myself from uploaders
  * Show line ordering variation in deb md5sums
  * Reset mtimes of test directories and ignore ctimes (Closes: deb#815171)
  * Add comparator for Postscript files
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sun Apr 10 2016 arun@gmx.de
- specfile:
  * fix update alternative (use %%{py3_ver}, touch sysconfig dir)
- update to version 51:
  * Team upload.
  * Re-upload, the last uploaded tarball was broken, missing test
    files.
- changes from version 50:
  * Remove myself from uploaders (Jérémy Bobbio)
  * Show line ordering variation in deb md5sums
  * Reset mtimes of test directories and ignore ctimes (Closes:
    [#815171])
  * Add comparator for Postscript files
* Sun Mar 13 2016 bwiedemann@suse.com
- We require python3-setuptools at runtime to work
* Thu Feb 18 2016 arun@gmx.de
- update to version 49:
  * Don't crash when we can't find the debug file in a matching debug
    package.  This repairs diffoscope for xserver-xorg and other
    packages.
  * Use libarchive to read metadata from ar archives. The output is
    more precise and less dependent on binutils version. The command
    line `ar` tool is not used any more so remove it from the required
    tools.
  * Split readelf --debug-dump output when examining ELF files. Based
    on a patch by Dhole.
  * Keep both .debug_str and .zdebug_str as ElfSection. Thanks to
    Niels Thykier for noticing the problem.
  * Fix a logic error in _install_debug_symbols. Thanks anthraxx for
    the report and the fix.
  * Use recursive containers for directory and only look at files with
    ending in .deb when looking for Build IDs. Both avoid looking at
    too many files when searching for matching debug packages. Thanks
    Helmut Grohne and Steven Chamberlain for the reports and
    tests. (Closes: deb#813052)
  * Add support for ICC profiles. This adds a Recommends on colord in
    Debian.
  * Harmonize spaces and commas in package list.
  * Update PPU files test data for FPC 3.0.0.
  * Update exepcted javap output for OpenJDK 1.8.
  * Stop specializing files from directories earlier than necessary.
  * Adding cd-iccdump package reference for Arch Linux.
  * Use HTTPS in Vcs-Git.
  * Bump standards version to 3.9.7, no changes needed.
  * Use /git/ instead /cgit/ in Vcs-Browser.
* Tue Feb  2 2016 sleep_walker@opensuse.org
- clean with spec-cleaner
- change Recommends: to Suggests:
- use update-alternatives mechanism for binary not to conflict with
  python2 variant of the package when there is one
* Sun Jan 31 2016 sleep_walker@opensuse.org
- add recommendations for tools which allows to interpret content
* Sun Jan 31 2016 sleep_walker@opensuse.org
- let there be diffoscope for openSUSE!
